OC.L10N.register(
    "spreed",
    {
    "a conversation" : "会話",
    "(Duration %s)" : "(時間 %s )",
    "You attended a call with {user1}" : "{user1} さんとの通話に参加しました",
    "_%n guest_::_%n guests_" : ["ゲスト %n 名"],
    "You attended a call with {user1} and {user2}" : "{user1} さんと {user2} さんの通話に参加しました",
    "You attended a call with {user1}, {user2} and {user3}" : "{user1}さん、{user2} さんと {user3} さんの通話に参加しました",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "{user1} さん、{user2} さん、 {user3} さんと {user4} さんの通話に参加しました",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "{user1} さん、{user2} さん、{user3} さん、{user4} さんと {user5} さんの通話に参加しました",
    "_%n other_::_%n others_" : ["他 %n 名"],
    "{actor} invited you to {call}" : "{actor} さんから {call} に招待されました",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "<strong>会話</strong>への招待、または<strong>着信</strong>があったとき",
    "Other activities" : "その他のアクティビティ",
    "Talk" : "トーク",
    "Guest" : "ゲスト",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Nextcloud Talkへようこそ!\nこのチャットでは、Nextcloud Talkで利用できる新機能について説明します。",
    "## New in Talk %s" : "## トークの新機能 %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft EdgeとSafariで音声通話とビデオ通話ができるようになりました",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- 1対1の会話が持続するようになり、誤ってグループ会話になってしまうことがなくなりました。また、参加者の1人が会話から退出しても、会話は自動的に削除されなくなりました。参加者の両方が退出した場合のみ、会話はサーバーから削除されます",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- チャットに「@all」を付けることで、参加者全員に通知できるようになりました",
    "- With the \"arrow-up\" key you can repost your last message" : "- ↑キーを押して、最後のメッセージを再投稿できます",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talkでコマンドを使用したり、「/help」をチャットメッセージとして送信したりできるようになりました",
    "- With projects you can create quick links between conversations, files and other items" : "- プロジェクトを使用すると、会話、ファイル、およびその他のアイテム間のクイックリンクを作成できます",
    "- You can now mention guests in the chat" : "- チャット内でゲストに対してメンションできるようになりました",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- 会話にロビーを設置できるようになりました。 これにより、モデレーターはチャットと通話に参加し、会議の準備をすることができるようになりました。その間、ユーザーとゲストは待つ必要があります",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- メッセージに直接返信できるようになり、メッセージの内容を詳しく説明できるようになりました",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "会話と参加者を検索すると、既存の会話もフィルタリングされるため、以前の会話を簡単に見つけることができます",
    "- You can now add custom user groups to conversations when the circles app is installed" : "サークルアプリのインストール時に、カスタムユーザーグループを会話に追加できるようになりました",
    "- Check out the new grid and call view" : "- 新しいグリッドと通話ビューをお試しください",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- デバイスからファイルをドラッグ＆ドロップして、チャットに直接アップロードきるようになりました",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- 共有ファイルをビューアアプリのチャットビューで直接開くようになりました",
    "- You can now search for chats and messages in the unified search in the top bar" : "-トップバーの統合検索でチャットやメッセージを検索できるようになりました",
    "- Spice up your messages with emojis from the emoji picker" : "- 絵文字ピッカーからの絵文字でメッセージを装飾",
    "- You can now change your camera and microphone while being in a call" : "- 通話中にカメラとマイクを変更できるようになりました",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- 会話に説明付きのコンテキストを与えて開き、ログインしたユーザーが会話を見つけて参加できるようになりました",
    "- See a read status and send failed messages again" : "- 既読ステータスを確認し、送信に失敗したメッセージを再送できるようになりました",
    "- Raise your hand in a call with the R key" : "- Rキーを押すと通話中に挙手できるようになりました",
    "- Join the same conversation and call from multiple devices" : "- 複数のデバイスから同一の会話や通話にさんかできるようになりました",
    "- Send voice messages, share your location or contact details" : "- ボイスメッセージを送信したり、現在地や連絡先の詳細を共有できるようになりました",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- 会話にグループを追加すると、グループメンバーが参加者として自動的に追加されるようになりました",
    "- A preview of your audio and video is shown before joining a call" : "- 通話に参加する前に、音声とビデオのプレビューがご確認いただけるようになりました",
    "- You can now blur your background in the newly designed call view" : "- 最新デザインの通話ビューで、背景をぼかすことが可能になりました",
    "- Moderators can now assign general and individual permissions to participants" : "- モデレーターは、参加者に一般および個別の権限を割り当てることができるようになりました",
    "- You can now react to chat messages" : "- チャットメッセージにリアクションが可能になりました",
    "- In the sidebar you can now find an overview of the latest shared items" : "- サイドバーで、最新の共有済みアイテムに関する概要を確認できるようになりました",
    "- Use a poll to collect the opinions of others or settle on a date" : "- アンケートを使用して他の人の意見を集めたり、日付を決められます",
    "- Configure an expiration time for chat messages" : "- チャットメッセージの有効期限を設定できます",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- 参加者が多数の場合は、他の人に通知せずに通話を開始できます。通話を開始してから個別に通話通知を送信できます。",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- 緊急でない場合は、受信者に通知せずにチャット メッセージを送信できます",
    "- Emojis can now be autocompleted by typing a \":\"" : "- 「:」を入力して絵文字を自動補完入力できるようになりました。",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- 「/」を入力して新しいスマートピッカーを起動し、さまざまなアイテムをリンクことができるようになりました。",
    "- Moderators can now create breakout rooms (requires the High-performance backend)" : "- 主催者がブレイクアウトルームを作成できるようになりました(要高性能バックエンド)",
    "- Calls can now be recorded (requires the High-performance backend)" : "- 通話を録音できるようになりました(要高性能バックエンド)",
    "- Conversations can now have an avatar or emoji as icon" : "- 会話にアバターまたは絵文字をアイコンとして含めることができるようになりました",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- ビデオ通話で背景をぼかすだけでなく、バーチャル背景も利用可能になりました",
    "- Reactions are now available during calls" : "- 通話中のリアクションが利用できるようになりました",
    "- Typing indicators show which users are currently typing a message" : "- 入力インジケーターは、どのユーザーが現在メッセージを入力しているか示します",
    "- Groups can now be mentioned in chats" : "- グループをチャットで言及できるようになりました",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "- 文字起こしプロバイダーアプリが登録されている場合、通話録音は自動的に文字起こしされます",
    "- Chat messages can be translated if a translation provider app is registered" : "- 翻訳プロバイダーアプリが登録されている場合、チャットメッセージを翻訳できます",
    "- **Markdown** can now be used in _chat_ messages" : "- **Markdown** が _chat_ メッセージで使用できるようになりました",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "- Webhook を使用してボットを実装できるようになりました。詳細については、ドキュメントを参照してください https://nextcloud-talk.readthedocs.io/en/latest/bot-list/",
    "- Set a reminder on a chat message to be notified later again" : "- チャットメッセージにリマインダーを設定すると後で再度通知されるようにできるようになりました",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- **Note to self** 会話を使用して、メモを取りデバイス間で情報を共有します",
    "- Captions allow to send a message with a file at the same time" : "- キャプションを使えば、メッセージとファイルを同時に送信できます",
    "- Video of the speaker is now visible while sharing the screen and call reactions are animated" : "- 画面共有中にスピーカーの映像が見えるようになり、通話のリアクションがアニメーションで表示されるようになった",
    "- Messages can now be edited by logged-in authors and moderators for 6 hours" : "- ログインした作成者とモデレーターが6時間以内はメッセージを編集できるようになりました",
    "- Unsent message drafts are now saved in your browser" : "- 未送信のメッセージの下書きはブラウザに保存されるようになりました",
    "- Text chatting can now be done in a federated way with other Talk servers" : "- 他のNextcloudのTalkサーバーと連携してテキストチャットできるようになりました",
    "- Moderators can now ban accounts and guests to prevent them from rejoining a conversation" : "- モデレータはアカウントとゲストを退室させ、会話に再度参加するのを禁止できるようになりました",
    "- Upcoming calls from linked calendar events and out-of-office replacements are now shown in conversations" : "- リンクされたカレンダーイベントや不在時の代理者からの通話が、会話画面に表示されるようになりました",
    "- Calls can now be done in a federated way with other Talk servers (requires the High-performance backend)" : "- 他のNextcloud Talk サーバーと連携して通話できるようになりました(要高性能バックエンド)",
    "- Introducing the Nextcloud Talk desktop client for Windows, macOS and Linux: %s" : "- Windows、macOS、Linux用Nextcloud Talkデスクトップ クライアントをリリース: %s",
    "- Summarize call recordings and unread messages in chats with the Nextcloud Assistant" : "- Nextcloudアシスタントを使用して、チャットの通話録音と未読メッセージを要約",
    "- Improved meetings with recognizing guests invited via their email address, import of participant lists, drafts for polls and downloading call participant lists" : "- 電子メールアドレス経由で招待されたゲストを識別、参加者リストのインポート、投票の下書き、および通話参加者リストのダウンロードによる会議の改善",
    "- Archive conversations to stay focused" : "- 会話をアーカイブして、必要なものに集中できるようになりました",
    "- Schedule a meeting into your calendar from within a conversation" : "- 会話内からカレンダーへ会議を予約する",
    "- Search for messages of the current conversation directly in the right sidebar" : "- 現在の会話のメッセージを右側のサイドバーで直接検索",
    "- See more conversations on a first glance with the new compact list (enable in the Talk settings)" : "- 新しいコンパクトなリストを使用して、より多くの会話を一目で確認できます (トーク設定で有効化)",
    "- Meeting conversations now sync the title and description from the calendar and are hidden with a search filter until they are close to the start" : "- 会議についての会話は、カレンダーでタイトルと説明が同期されるようになりました。開始時間が近づくまで、検索フィルターでは非表示になります",
    "- Mark conversations as sensitive in the notification settings, to hide the message content from the conversation list and notifications" : "- 通知設定で会話を機密としてマークすると、会話リストと通知からメッセージの内容が非表示になります",
    "- To receive push notifications during \"Do not disturb\", mark conversations as important" : "- 会話に重要マークを付けると「応答不可」中にもプッシュ通知を受信できます",
    "- Add other participants to a one-to-one call to create a new group call on the fly" : "- この1対1通話に他の参加者を追加して、その場で新しいグループ通話を作成する",
    "- Use threads to keep your chat and discussions organized" : "- スレッドを使ってチャットや議論を整理",
    "- Live transcriptions now available during the call (requires the live-transcription ExApp and the High-performance backend)" : "- 通話中にライブ文字起こしが利用できるようになりました (ライブ文字起こしのExAppと高性能バックエンドが必要です)",
    "Talk updates ✅" : "Talk アップデート ✅",
    "Reaction deleted by author" : "作成者により削除されたリアクション",
    "{actor} created the conversation" : "{actor} さんが会話を作成しました",
    "You created the conversation" : "会話を作成しました",
    "System created the conversation" : "システムが会話を作成しました",
    "An administrator created the conversation" : "管理者が会話を作成しました",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor}が会話を%1$sから%2$sにリネームしました",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "会話を%1$sから%2$sにリネームしました",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "管理者が会話の名前を \"%1$s\" から \"%2$s\" に変更しました",
    "{actor} set the description" : "{actor} が説明を設定しました",
    "You set the description" : "詳細を設定しました",
    "An administrator set the description" : "管理者が説明を設定しました",
    "{actor} removed the description" : "{actor} が詳細を削除しました",
    "You removed the description" : "詳細を削除しました",
    "An administrator removed the description" : "管理者が詳細を削除しました",
    "You started a silent call" : "あなたはサイレントコールを開始しました",
    "{actor} started a silent call" : "{actor} はサイレントコールを開始しました",
    "You started a call" : "通話を開始しました",
    "Outgoing call" : "発信",
    "{actor} started a call" : "{actor}が通話を開始しました",
    "Incoming call" : "着信",
    "{actor} joined the call" : "{actor} が通話に参加しました",
    "You joined the call" : "あなたはこの通話に参加しました",
    "{actor} left the call" : "{actor} が通話を離脱しました",
    "You left the call" : "あなたはこの通話を離脱しました",
    "{actor} unlocked the conversation" : "{actor} が会話のロックを解除しました",
    "You unlocked the conversation" : "会話のロックを解除しました",
    "An administrator unlocked the conversation" : "管理者が会話のロックを解除しました",
    "{actor} locked the conversation" : "{actor} が会話をロックしました",
    "You locked the conversation" : "会話をロックしました",
    "An administrator locked the conversation" : "管理者が会話をロックしました",
    "{actor} limited the conversation to the current participants" : "{actor} は会話を現在の参加者に限定しました",
    "You limited the conversation to the current participants" : "会話を現在の参加者に限定しました",
    "An administrator limited the conversation to the current participants" : "管理者は会話を現在の参加者に制限しました",
    "{actor} opened the conversation to registered users" : "{actor} が登録ユーザーに会話を公開しました",
    "You opened the conversation to registered users" : "登録ユーザーへ会話を公開しました",
    "An administrator opened the conversation to registered users" : "管理者が登録ユーザーへ会話を公開しました",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "{actor} は、登録済みユーザーおよび Guests アプリで作成されたユーザーに会話を公開しました",
    "You opened the conversation to registered users and users created with the Guests app" : "登録済みユーザーおよび Guests アプリで作成されたユーザーに会話を公開しました",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "管理者が登録済みユーザーおよび Guests アプリで作成されたユーザーに会話を公開しました",
    "The conversation is now open to everyone" : "全員への会話が開始されました",
    "{actor} opened the conversation to everyone" : "{actor}が全員への会話を開始しました",
    "You opened the conversation to everyone" : "全員への会話を開始しました",
    "{actor} restricted the conversation to moderators" : "{actor} が会話をモデレーターに制限しました",
    "You restricted the conversation to moderators" : "会話をモデレーターに限定しました",
    "{actor} started breakout rooms" : "{actor} が子会議室を開始しました",
    "You started breakout rooms" : "子会議室を開始しました",
    "{actor} stopped breakout rooms" : "{actor} が子会議室を停止しました",
    "You stopped breakout rooms" : "子会議室を停止しました",
    "{actor} allowed guests" : "{actor} がゲストを許可しました",
    "You allowed guests" : "あなたがゲストを許可しました",
    "An administrator allowed guests" : "管理者がゲストを許可しました",
    "{actor} disallowed guests" : "{actor}がゲストを拒否しました",
    "You disallowed guests" : "ゲストを拒否しました",
    "An administrator disallowed guests" : "管理者がゲストを拒否しました",
    "{actor} set a password" : "{actor} がパスワードを設定しました",
    "You set a password" : "パスワードを設定する",
    "An administrator set a password" : "管理者がパスワードを設定しました",
    "{actor} removed the password" : "{actor} がパスワードを削除しました",
    "You removed the password" : "パスワードを削除しました",
    "An administrator removed the password" : "管理者がパスワードを削除しました",
    "{actor} added {user}" : "{actor} が {user} を追加しました",
    "You joined the conversation" : "会話に参加しました",
    "{actor} joined the conversation" : "{actor}が会話に参加しました",
    "You added {user}" : "{user}を追加しました",
    "{actor} added you" : "{actor}があなたを追加しました",
    "An administrator added you" : "管理者があなたを追加しました",
    "An administrator added {user}" : "管理者が {user} を追加しました",
    "You left the conversation" : "会話から抜けました",
    "{actor} left the conversation" : "{actor}が会話から抜けました",
    "{actor} removed {user}" : "{actor} が {user} を削除しました。",
    "You removed {user}" : "{user}を削除しました",
    "{actor} removed you" : "{actor}があなたを削除しました",
    "An administrator removed you" : "管理者があなたを外しました",
    "An administrator removed {user}" : "管理者が {user}を外しました",
    "{actor} invited {federated_user}" : "{actor} が {federated_user} を招待しました",
    "You invited {federated_user}" : "あなたが {federated_user} を招待しました",
    "You accepted the invitation" : "あなたはこの招待を受け入れました",
    "{actor} invited you" : "{actor} さんがあなたを招待しました",
    "An administrator invited you" : "管理者があなたを招待しました",
    "An administrator invited {federated_user}" : "管理者が {federated_user} を招待しました",
    "{federated_user} accepted the invitation" : "{federated_user} さんが招待を承認しました",
    "{actor} removed {federated_user}" : "{actor} さんが {federated_user} さんを削除しました",
    "You removed {federated_user}" : "あなたが {federated_user} さんを削除しました",
    "An administrator removed {federated_user}" : "管理者が {federated_user} さんを削除しました",
    "{federated_user} declined the invitation" : "{federated_user} さんが招待を拒否しました",
    "{actor} added group {group}" : "{actor} がグループ {group} を追加しました",
    "You added group {group}" : "グループ {group} を追加しました",
    "An administrator added group {group}" : "管理者が {group} グループを追加しました",
    "{actor} removed group {group}" : "{actor} がグループ {group} を削除",
    "You removed group {group}" : "グループ {group} を削除しました",
    "An administrator removed group {group}" : "管理者が {group} グループを削除しました",
    "You removed team {circle}" : "{circle}を削除しました",
    "An administrator removed team {circle}" : "管理者がチーム{circle}を削除しました",
    "{actor} added {phone}" : "{actor} が {phone} を追加しました",
    "You added {phone}" : "あなたが {phone} を追加しました",
    "An administrator added {phone}" : "管理者が {phone} を追加しました",
    "{actor} removed {phone}" : "{actor} が {phone} を削除しました",
    "You removed {phone}" : "あなたが {phone} を削除しました",
    "An administrator removed {phone}" : "管理者が {phone} を削除しました",
    "{actor} promoted {user} to moderator" : "{actor} が {user} をモデレーターに昇格しました",
    "You promoted {user} to moderator" : "{user} をモデレータに昇格しました",
    "{actor} promoted you to moderator" : "{actor}があなたをモデレータに昇格させました",
    "An administrator promoted you to moderator" : "管理者があなたをモデレータに昇格させました",
    "An administrator promoted {user} to moderator" : "管理者が {user}をモデレータに昇格させました",
    "{actor} demoted {user} from moderator" : "{actor}が{user}をモデレーターから降格させました",
    "You demoted {user} from moderator" : "{user}をモデレーターから降格させました",
    "{actor} demoted you from moderator" : "{actor}があなたをモデレーターから降格させました",
    "An administrator demoted you from moderator" : "管理者があなたをモデレーターから降格させました",
    "An administrator demoted {user} from moderator" : "管理者が {user}をモデレーターから降格させました",
    "{actor} shared a file which is no longer available" : "{actor}は使用できなくなったファイルを共有しました",
    "You shared a file which is no longer available" : "使用できなくなったファイルを共有しました",
    "The shared location is malformed" : "共有場所の形式が正しくありません",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} が、この会話を他のチャットと同期するようにMatterbridgeを設定しました",
    "You set up Matterbridge to synchronize this conversation with other chats" : "この会話を他のチャットシステムと同期するようにMatterbridgeを設定します",
    "{actor} created thread {title}" : "{actor}がスレッド{title}を作成した",
    "You created thread {title}" : "{title}スレッドを作成しました",
    "{actor} updated the Matterbridge configuration" : "{actor} がMatterbridgeの構成を更新しました。",
    "You updated the Matterbridge configuration" : "Matterbridgeの構成を更新しました。",
    "{actor} removed the Matterbridge configuration" : "{actor} はMatterbridge構成を削除しました",
    "You removed the Matterbridge configuration" : "Matterbridge構成を削除しました",
    "{actor} started Matterbridge" : "{actor} がMatterbridgeを開始しました",
    "You started Matterbridge" : "Matterbridgeを開始しました",
    "{actor} stopped Matterbridge" : "{actor} がMatterbridgeを停止しました",
    "You stopped Matterbridge" : "Matterbridgeを停止しました",
    "{actor} deleted a message" : "{actor} がメッセージを削除しました",
    "You deleted a message" : "メッセージを削除しました",
    "{actor} edited a message" : "{actor} がメッセージを編集しました",
    "You edited a message" : "あなたがメッセージを編集しました",
    "{actor} deleted a reaction" : "{actor} さんがリアクションを削除しました",
    "You deleted a reaction" : "あなたはリアクションを削除しました",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["メッセージの有効期限を%n週間に設定しました。"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["メッセージの有効期限を%n日に設定しました。"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["メッセージの有効期限を%n時間に設定しました。"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["メッセージの有効期限を%n分に設定しました。"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor}がメッセージの有効期限を%n週間に設定しました。"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor}がメッセージの有効期限を%n日に設定しました。"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor}がメッセージの有効期限を%n時間に設定しました。"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor}がメッセージの有効期限を%n分に設定しました。"],
    "{actor} disabled message expiration" : "{actor} がメッセージの有効期限を無効にしました",
    "You disabled message expiration" : "メッセージの有効期限を無効にしました",
    "{actor} cleared the history of the conversation" : "{actor} が会話の履歴を削除しました",
    "You cleared the history of the conversation" : "会話の履歴を削除しました",
    "{actor} set the conversation picture" : "{actor} がこのチャットの画像を設定しました",
    "You set the conversation picture" : "このチャットの画像を設定しました",
    "{actor} removed the conversation picture" : "{actor}がこのチャットの画像を削除しました",
    "You removed the conversation picture" : "このチャットの画像を削除しました",
    "{actor} ended the poll {poll}" : "{actor} が投票 {poll} を終了した",
    "You ended the poll {poll}" : "あなたが投票 {poll} を終了した",
    "{actor} started the video recording" : "{actor} がビデオ録画を開始しました",
    "You started the video recording" : "あなたがビデオ録画を開始しました",
    "{actor} stopped the video recording" : "{actor} がビデオ録画を停止しました",
    "You stopped the video recording" : "あなたがビデオ録画を停止しました",
    "{actor} started the audio recording" : "{actor} が音声録音を開始しました",
    "You started the audio recording" : "あなたが音声録音を開始しました",
    "{actor} stopped the audio recording" : "{actor} が音声録音を中止しました",
    "You stopped the audio recording" : "あなたが音声録音を中止しました",
    "The recording failed" : "レコーディングに失敗しました",
    "Someone voted on the poll {poll}" : "誰かが投票 {poll} しました",
    "Message deleted by author" : "作成者によって削除されたメッセージ",
    "Message deleted by {actor}" : "{actor} によって削除されたメッセージ",
    "Message deleted by you" : "あなたが削除したメッセージ",
    "Deleted user" : "ユーザーを削除",
    "Unknown number" : "不明な番号",
    "Administration" : "管理",
    "System" : "システム",
    "%s (guest)" : "%s(ゲスト)",
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} さんが %n 人のゲストとの通話を終了しました (通話時間 {duration})"],
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} さんが {user1} さんとの通話を終了しました (通話時間 {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} さんが {user1} さんと {user2} さんとの通話を終了しました (通話時間 {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} さんが {user1} さん、 {user2} さんと {user3} さんとの通話を終了しました (通話時間 {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} さんが {user1} さん、 {user2} さん、 {user3} さん、 {user4} さんとの通話を終了しました (通話時間 {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} さんが {user1} さん、 {user2} さん、 {user3} さん、 {user4} さん、{user5} さんとの通話を終了しました (通話時間 {duration})",
    "Message of {user} in {conversation}" : "{conversation} の {user} のメッセージ",
    "Message of {user}" : "{user} のメッセージ",
    "Message of a deleted user in {conversation}" : "{conversation} の削除されたユーザーのメッセージ",
    "Talk conversations" : "会話",
    "Call %s" : "電話 %s",
    "An error occurred. Please contact your administrator." : "エラーが発生しました。管理者に連絡してください。",
    "Storage quota exceeded" : "ストレージの割り当てを超過しました",
    "File not found" : "ファイルが見つかりません",
    "File is not shared, or shared but not with the user" : "ファイルが共有されていないか、対象ユーザーを除いて共有されています",
    "No account available to delete." : "削除するアカウントがありません。",
    "Poll" : "投票",
    "No image file provided" : "画像ファイルが提供されていません",
    "File is too big" : "ファイルが大きすぎます",
    "Invalid file provided" : "無効なファイルが提供されました",
    "Invalid image" : "無効な画像",
    "Unknown filetype" : "不明なファイルタイプ",
    "Talk mentions" : "Talk",
    "Say hi to your friends and colleagues!" : "友達や同僚に挨拶しましょう！",
    "No unread mentions" : "未読はありません",
    "Call in progress" : "呼び出し中",
    "You were mentioned" : "あなたについて言及されました",
    "Write to conversation" : "会話に書き込む",
    "Writes event information into a conversation of your choice" : "選択した会話にイベント情報を書き込みます",
    "Conversation invitation" : "会話への招待",
    "Description" : "詳細",
    "You can also dial-in via phone with the following details" : "次の詳細を使用して電話でダイヤルインすることもできます",
    "Dial-in information" : "ダイヤルイン情報",
    "Meeting ID" : "ミーティングID",
    "Your PIN" : "あなたのPIN",
    "Meeting" : "会議",
    "Password request: %s" : "パスワードのリクエスト :%s",
    "Private conversation" : "プライベート会話",
    "Deleted user (%s)" : "削除済みユーザー(%s)",
    "Failed to upload call recording" : "通話録音のアップロードに失敗しました",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "レコーディングサーバーは、通話 {call} の録音のアップロードに失敗しました。管理者に連絡してください。",
    "Share to chat" : "チャットに共有する",
    "Dismiss notification" : "通知を閉じる",
    "Call recording now available" : "通話レコーディングが利用可能です",
    "The recording for the call in {call} was uploaded to {file}." : "{call} の通話の録音は {file} にアップロードされました。",
    "Transcript now available" : "トランスクリプトは現在利用可能です",
    "The transcript for the call in {call} was uploaded to {file}." : "{call} の通話の録音は {file} にアップロードされました。",
    "Failed to transcript call recording" : "通話レコーディングのトランスクリプトに失敗しました",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "サーバーは {call} のコールの {file} の通話レコーディングを transcript することに失敗しました。管理者に連絡してください。",
    "Call summary now available" : "通話要約が利用可能になりました",
    "The summary for the call in {call} was uploaded to {file}." : "{call}通話の要約が {file}にアップロードされました。",
    "{user1} invited you to join {roomName} on {remoteServer}" : "{user1} が {remoteServer} 上の {roomName} に参加するようにあなたを招待しました",
    "Accept" : "承諾",
    "Decline" : "拒否",
    "{user1} invited you to a federated conversation" : "{user1} があなたをフェデレーション会話に招待しました",
    "New message" : "新規メッセージ",
    "Reminder" : "リマインダー",
    "Notification" : "通知",
    "Reminder: You in {call}" : "リマインダー: You in {call}",
    "Reminder: {user} in {call}" : "リマインダー: {user} in {call}",
    "Reminder: Deleted user in {call}" : "リマインダー: {call} で削除されたユーザー",
    "Reminder: {guest} (guest) in {call}" : "リマインダー: {guest} (guest) in {call}",
    "Reminder: Guest in {call}" : "リマインダー: Guest in {call}",
    "{user} reacted with {reaction}" : "{user} が {reaction} で反応しました",
    "{user} reacted with {reaction} in {call}" : "{user} は {call} で {reaction} で反応しました",
    "Deleted user reacted with {reaction} in {call}" : "削除されたユーザーは {call} で {reaction} で反応しました",
    "{guest} (guest) reacted with {reaction} in {call}" : "{guest} (guest) は {reaction} で {call} に反応しました",
    "Guest reacted with {reaction} in {call}" : "ゲスト は {call} で {reaction} で反応しました",
    "{user} in {call}" : "{call} の {user}",
    "Deleted user in {call}" : "{call} から削除されたユーザー",
    "{guest} (guest) in {call}" : "{call}の(ゲスト) {guest}",
    "Guest in {call}" : "{call} のゲスト",
    "{user} sent you a private message" : "{user} はあなたにプライベートなメッセージを送信しました",
    "{user} sent a message in conversation {call}" : "{user}は会話{call}でメッセージを送りました",
    "A deleted user sent a message in conversation {call}" : "削除されたユーザーが会話 {call} でメッセージを送信しました",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (guest) 会話 {call} にメッセージを送信しました",
    "A guest sent a message in conversation {call}" : "ゲストが会話 {call} でメッセージを送信しました",
    "{user} replied to your private message" : "{user} はあなたのプライベートなメッセージに返信しました",
    "{user} replied to your message in conversation {call}" : " {user} が会話{call}内のメッセージに返信しました",
    "A deleted user replied to your message in conversation {call}" : "削除されたユーザーが会話 {call} であなたのメッセージに返信しました",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (guest) が会話 {call} であなたのメッセージに返信しました",
    "A guest replied to your message in conversation {call}" : "ゲストが会話 {call} であなたのメッセージに返信しました",
    "Reminder: You in private conversation {call}" : "リマインダー：あなたは非公開の会話で {call} しています",
    "Reminder: A deleted user in private conversation {call}" : "リマインダー：非公開の会話 {call} で削除されたユーザー",
    "Reminder: {user} in private conversation" : "リマインダー：{user} は非公開の会話にいます",
    "Reminder: You in conversation {call}" : "リマインダー：あなたは会話で {call} しています",
    "Reminder: {user} in conversation {call}" : "リマインダー：{user} は会話で {call} しています",
    "Reminder: A deleted user in conversation {call}" : "リマインダー：非公開の会話 {call} で削除されたユーザー",
    "Reminder: {guest} (guest) in conversation {call}" : "リマインダー：{guest} (guest) は会話 {call} にいます",
    "Reminder: A guest in conversation {call}" : "リマインダー：ゲストは会話 {call} にいます",
    "{user} reacted with {reaction} to your private message" : "{user} さんが、あなたとのプライベートメッセージに {reaction} とリアクションしました",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} さんが、会話 {call} 内でのあなたのメッセージに対して {reaction} とリアクションしました",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "削除されたユーザーが、会話 {call} 内でのあなたのメッセージに対して {reaction} とリアクションしました",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest} (ゲスト) さんが、会話 {call} 内でのあなたのメッセージに対して {reaction} とリアクションしました",
    "A guest reacted with {reaction} to your message in conversation {call}" : "ゲストさんが、会話 {call} 内でのあなたのメッセージに対して {reaction} とリアクションしました",
    "{user} mentioned you in a private conversation" : "{user}がプライベートな会話であなたについて話しをしました",
    "{user} mentioned group {group} in conversation {call}" : "{user} は会話 {call} でグループ {group} に言及しました",
    "{user} mentioned everyone in conversation {call}" : "{user} は会話 {call} で全員に言及しました",
    "{user} mentioned you in conversation {call}" : "{user}は会話 {call} であなたについて話しをしました",
    "A deleted user mentioned group {group} in conversation {call}" : "削除されたユーザーが会話 {call} でグループ {group} に言及しました",
    "A deleted user mentioned everyone in conversation {call}" : "削除されたユーザーは会話 {call} で全員に言及しました",
    "A deleted user mentioned you in conversation {call}" : "削除されたユーザーが会話 {call} であなたについて話しをしました",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{guest} (guest) が会話 {call} でグループ {group} に言及しました",
    "{guest} (guest) mentioned everyone in conversation {call}" : "{guest} (guest) は会話 {call} で全員に言及しました",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (guest) が会話 {call} であなたに話しをしました",
    "A guest mentioned group {group} in conversation {call}" : "ゲストが会話 {call} でグループ {group} に言及しました",
    "A guest mentioned everyone in conversation {call}" : "ゲストが会話 {call} で全員に言及しました",
    "A guest mentioned you in conversation {call}" : "ゲストが会話{call}であなたについて話しをしました",
    "View message" : "メッセージを表示する",
    "Dismiss reminder" : "リマインダーを解除",
    "View chat" : "チャットを見る",
    "{user} invited you to a group conversation: {call}" : "{user}がグループ会話{call}にあなたを招待しました",
    "Join call" : "通話開始",
    "Answer call" : "応答",
    "{user} would like to talk with you" : "{user} からの通話要請があります",
    "Call back" : "折り返し電話",
    "You missed a call from {user}" : "{user}からの着信に応答できませんでした。",
    "A group call has started in {call}" : "{call} のグループ通話が開始されました",
    "You missed a group call in {call}" : "{user}からのグループ着信に応答できませんでした。",
    "{email} is requesting the password to access {file}" : "{email}は{file}にアクセスするためのパスワードをリクエストしています",
    "{email} tried to request the password to access {file}" : "{email} が {file} にアクセスするためのパスワードを要求しようとしました",
    "Someone is requesting the password to access {file}" : "誰かが{file}にアクセスするためのパスワードを要求しています",
    "Someone tried to request the password to access {file}" : "誰かが {file} にアクセスするためのパスワードを要求しようとしました",
    "Open settings" : "設定を開く",
    "Hosted signaling server added" : "ホストされたシグナリングサーバーを追加しました",
    "The hosted signaling server is now configured and will be used." : "ホストされたシグナリングサーバーが設定され、使用されるようになります。",
    "Hosted signaling server removed" : "ホストされたシグナリングサーバーを削除しました",
    "The hosted signaling server was removed and will not be used anymore." : "ホストされたシグナリングサーバーが削除され、使用できないようになります。",
    "Hosted signaling server changed" : "ホストされたシグナリングサーバーを変更しました",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "ホストされたシグナリングサーバーのアカウントのステータスが\"{oldstatus}\"から\"{newstatus}\"に変更されました。",
    "pending" : "保留中",
    "active" : "有効",
    "expired" : "有効期限切れ",
    "blocked" : "ブロックされた",
    "error" : "エラー",
    "The certificate of {host} expires in {days} days" : "{host} の証明書は {days} 日後に期限切れになります",
    "The certificate of {host} expired" : "{host} の証明書が期限切れです",
    "Contact via Talk" : "Talk経由で連絡",
    "Open Talk" : "公開トーク",
    "Default" : "デフォルト",
    "Presentation" : "プレゼンテーション",
    "Conversations" : "会話",
    "Messages in current conversation" : "現在の会話のメッセージ",
    "{user}" : "{user}",
    "Messages" : "メッセージ",
    "{user} in {conversation}" : "{conversation} の {user}",
    "Messages in other conversations" : "他の会話のメッセージ",
    "One-to-one rooms always need to show the other users avatar" : "1対1のルームでは、常に相手ユーザーのアバターを表示する必要があります",
    "Invalid emoji character" : "無効な絵文字",
    "Invalid background color" : "無効な背景色",
    "Avatar image is not square" : "アバター画像が正方形ではありません",
    "Room {number}" : "ルーム {number}",
    "Favorites" : "お気に入り",
    "Other" : "その他",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "トライアルサーバーに到達できないため、トライアルのリクエストに失敗しました。後ほどもう一度お試しください。",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "このインスタンスの認証に問題があります。もしかしたら、外部からURLを確認しても届かないのかもしれません。",
    "Something unexpected happened." : "想定外のことが起きました。",
    "The URL is invalid." : "無効なURLです。",
    "An HTTPS URL is required." : "HTTPS URLは必須です。",
    "The email address is invalid." : "無効なメールアドレスです。",
    "The language is invalid." : "無効な言語です。",
    "The country is invalid." : "無効な国名です。",
    "There is a problem with the request of the trial. Please check your logs for further information." : "トライアルリクエストに問題があります。詳細はログを確認してください。",
    "Too many requests are send from your servers address. Please try again later." : "あなたのサーバーアドレスからのリクエストが多すぎます。後でもう一度ためしてください。",
    "There is already a trial registered for this Nextcloud instance." : "このNextcloudのインスタンスには、すでにトライアルが登録されています。",
    "Something unexpected happened. Please try again later." : "想定外のことが起きました。後ほどもう一度お試しください。",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "トライアルサーバー動作不良のたため、トライアルリクエストに失敗しました。後ほどもう一度お試しください。",
    "Trial requested but failed to get account information. Please check back later." : "トライアルを要求しましたが、アカウント情報を取得できませんでした。後ほど確認してください。",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "この認証要求に問題があります。もしかしたら、外部からURLを確認しても届かないのかもしれません。",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "トライアルサーバー動作不良ため、アカウント情報の取得に失敗しました。後ほど確認してください。",
    "There is a problem with fetching the account information. Please check your logs for further information." : "アカウント情報の取得中に問題が生じました。詳細はログを確認してください。",
    "There is no such account registered." : "そのようなアカウントは登録されていません。",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "トライアルサーバーにアクセスできないため、アカウント情報の取得に失敗しました。後ほど確認してください。",
    "Deleting the hosted signaling server account failed. Please check back later." : "ホストされたシグナリングサーバーのアカウント削除に失敗しました。後ほど確認してください。",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "トライアルサーバー動作不良のため、アカウントの削除に失敗しました。後ほど確認してください。",
    "There is a problem with deleting the account. Please check your logs for further information." : "アカウントの削除中に問題が生じました。詳しくはログをご確認ください。",
    "Too many requests are sent from your servers address. Please try again later." : "サーバーアドレスから送信されるリクエストが多すぎます。後でもう一度やり直してください。",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "トライアルサーバーにアクセスできないため、アカウントの削除に失敗しました。後ほど確認してください。",
    "Note to self" : "自分へのメモ",
    "A place for your private notes, thoughts and ideas" : "あなたの非公開のメモ、思考とアイデアの場所",
    "**Nextcloud Talk** is a secure, self-hosted communication platform that integrates seamlessly with the Nextcloud ecosystem.\n\n#### Key Features of Nextcloud Talk:\n\n* Chat and messaging in private and group chats\n* Voice and video calls\n* File sharing and integration with other Nextcloud apps\n* Customizable conversation settings, moderation and privacy controls\n* Web, desktop and mobile (iOS and Android)\n* Private & secure communication\n\n Find out more in the [user documentation](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html)." : "**Nextcloud Talk** は、Nextcloudエコシステムとシームレスに統合された安全なセルフホスト型通信プラットフォームです。\n\n#### Nextcloud Talkの主な機能:\n\n* プライベートチャットとグループチャットでのチャットとメッセージング\n* 音声通話とビデオ通話\n* ファイル共有と他のNextcloudアプリとの統合\n* カスタマイズ可能な会話設定、モデレーション、プライバシー制御\n* Web、デスクトップ、モバイル(iOSおよびAndroid)\n* プライベートで安全な通信\n\n詳細については、[ユーザー ドキュメント](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html) をご覧ください",
    "# Welcome to Nextcloud Talk\n\nNextcloud Talk is a private and powerful messaging app that integrates with Nextcloud. Chat in private or group conversations, collaborate over voice and video calls, organize webinars and events, customize your conversations and more." : "#Nextcloudトークへようこそ\n\nNextcloud Talkは、Nextcloudと統合されたプライベートで強力なメッセージングアプリです。プライベートまたはグループの会話でチャットしたり、音声通話やビデオ通話で共同作業したり、ウェビナーやイベントを企画したり、会話をカスタマイズしたりできます。",
    "## 🎨 Format texts to create rich messages\n\nIn Nextcloud Talk, you can use Markdown syntax to format your messages. For example, apply **bold** or *italic* formatting, or `highlight texts as code`. You can even create tables and add headings to your text.\n\nNeed to fix a typo or change formatting? Edit your message by clicking \"Edit message\" in the message menu." : "## 🎨 テキストの書式を設定してリッチメッセージを作成する\n\nNextcloud Talkでは、Markdown構文を使用してメッセージを修飾できます。たとえば、**太字** または *斜体* の書式設定を適用したり、`テキストをコードとして強調表示`したりします。表を作成し、テキストに見出しを追加することも可能です。\n\nタイプミスを修正したり、書式を修正したりする必要がありますか? メッセージメニューから「メッセージの編集」をクリックしてメッセージを編集できます。",
    "## 🔗 Add attachments and links\n\nAttach files from your Nextcloud Hub using the \"+\" button. Share items from Files and various Nextcloud apps. Some apps even support interactive widgets, for example, the Text app." : "## 🔗添付ファイルやリンクを追加します\n\n「+」ボタンを使用すれば、Nextcloud Hubからファイルを添付できます。ファイルやさまざまなNextcloudアプリからもアイテムを共有できます。 Textアプリなど、一部のアプリではインタラクティブなウィジェットもサポートされています。",
    "## 💭 Let the conversations flow: mention users, react to messages and more\n\nYou can mention everybody in the conversation by using %s or mention specific participants by typing \"@\" and picking their name from the list." : "## 💭 会話をスムーズに：ユーザーにメンションしたり、メッセージに反応したりしましょう\n\n%sを使用して会話中の全員にメンションしたり、「@」を入力してリストから名前を選択して特定の参加者にメンションできます。",
    "## ✨ Do more with Smart Picker\n\nSimply type \"/\" or go to the \"+\" menu to open the Smart Picker where you can attach various content to your messages. You can configure the Smart Picker to be able to add items from Nextcloud apps, GIFs, map locations, AI generated content and much more." : "## ✨ スマート ピッカーでもっといろんな事を呼び出せます\n\n「/」を入力するか、「+」メニューからスマート ピッカーを開き、メッセージにさまざまなコンテンツを添付できます。 スマートピッカーを設定すると、Nextcloudアプリ、GIF、地図上の場所、AI生成コンテンツなどからアイテムを追加できます。",
    "## ⚙️ Manage conversation settings\n\nIn the conversation menu, you can access various settings to manage your conversations, such as:\n* Edit conversation info\n* Manage notifications\n* Apply numerous moderation rules\n* Configure access and security\n* Enable bots\n* and more!" : "⚙️ 会話管理設定 \n\n会話の管理画面で以下を設定できます：\n* 会話情報の編集 \n* 通知の管理 \n* 各種モデレーションルールの適用 \n* アクセスとセキュリティの設定 \n* ボットの有効化 \n* その他！",
    "Andorra" : "アンドラ",
    "United Arab Emirates" : "アラブ首長国連邦",
    "Afghanistan" : "アフガニスタン",
    "Antigua and Barbuda" : "アンティグア・バーブーダ",
    "Anguilla" : "アンギラ",
    "Albania" : "アルバニア",
    "Armenia" : "アルメニア",
    "Angola" : "アンゴラ",
    "Antarctica" : "南極大陸",
    "Argentina" : "アルゼンチン",
    "American Samoa" : "アメリカ領サモア",
    "Austria" : "オーストリア",
    "Australia" : "オーストラリア",
    "Aruba" : "アルバ",
    "Åland Islands" : "オーランド諸島",
    "Azerbaijan" : "アゼルバイジャン",
    "Bosnia and Herzegovina" : "ボスニア・ヘルツェゴビナ",
    "Barbados" : "バルバドス",
    "Bangladesh" : "バングラデシュ",
    "Belgium" : "ベルギー",
    "Burkina Faso" : "ブルキナファソ",
    "Bulgaria" : "ブルガリア",
    "Bahrain" : "バーレーン",
    "Burundi" : "ブルンジ共和国",
    "Benin" : "ベナン",
    "Saint Barthélemy" : "サン・バルテルミー島",
    "Bermuda" : "バミューダ諸島",
    "Brunei Darussalam" : "ブルネイ・ダルサラーム国",
    "Bolivia, Plurinational State of" : "ボリビア多民族国家",
    "Bonaire, Sint Eustatius and Saba" : "ボネール、シント・ユースタティウスおよびサバ",
    "Brazil" : "ブラジル",
    "Bahamas" : "バハマ",
    "Bhutan" : "ブータン",
    "Bouvet Island" : "ブーベ島",
    "Botswana" : "ボツワナ",
    "Belarus" : "ベラルーシ",
    "Belize" : "ベリーズ",
    "Canada" : "カナダ",
    "Cocos (Keeling) Islands" : "ココス（キーリング）諸島",
    "Congo, the Democratic Republic of the" : "コンゴ民主共和国",
    "Central African Republic" : "中央アフリカ共和国",
    "Congo" : "コンゴ共和国",
    "Switzerland" : "スイス",
    "Côte d'Ivoire" : "コートジボワール",
    "Cook Islands" : "クック諸島",
    "Chile" : "チリ",
    "Cameroon" : "カメルーン",
    "China" : "中華人民共和国",
    "Colombia" : "コロンビア共和国",
    "Costa Rica" : "コスタリカ",
    "Cuba" : "キューバ",
    "Cabo Verde" : "カーボベルデ",
    "Curaçao" : "キュラソー島",
    "Christmas Island" : "クリスマス諸島",
    "Cyprus" : "キプロス共和国",
    "Czechia" : "チェコ",
    "Germany" : "ドイツ",
    "Djibouti" : "ジブチ",
    "Denmark" : "デンマーク",
    "Dominica" : "ドミニカ国",
    "Dominican Republic" : "ドミニカ共和国",
    "Algeria" : "アルジェリア民主人民共和国",
    "Ecuador" : "エクアドル",
    "Estonia" : "エストニア",
    "Egypt" : "エジプト",
    "Western Sahara" : "西サハラ",
    "Eritrea" : "エリトリア",
    "Spain" : "スペイン",
    "Ethiopia" : "エチオピア",
    "Finland" : "フィンランド",
    "Fiji" : "フィジー",
    "Falkland Islands (Malvinas)" : "フォークランド（マルビナス）諸島",
    "Micronesia, Federated States of" : "ミクロネシア連邦",
    "Faroe Islands" : "フェロー諸島",
    "France" : "フランス",
    "Gabon" : "ガボン",
    "United Kingdom of Great Britain and Northern Ireland" : "イギリス",
    "Grenada" : "グレナダ",
    "Georgia" : "ジョージア",
    "French Guiana" : "フランス領ギアナ",
    "Guernsey" : "ガーンジー",
    "Ghana" : "ガーナ",
    "Gibraltar" : "ジブラルタル",
    "Greenland" : "グリーンランド",
    "Gambia" : "ガンビア",
    "Guinea" : "ギニア共和国",
    "Guadeloupe" : "グアドループ",
    "Equatorial Guinea" : "赤道ギニア共和国",
    "Greece" : "ギリシャ",
    "South Georgia and the South Sandwich Islands" : "サウスジョージア・サウスサンドウィッチ諸島",
    "Guatemala" : "グアテマラ",
    "Guam" : "グアム",
    "Guinea-Bissau" : "ギニアビサウ共和国",
    "Guyana" : "ガイアナ",
    "Hong Kong" : "香港",
    "Heard Island and McDonald Islands" : "ハード島とマクドナルド諸島",
    "Honduras" : "ホンジュラス",
    "Croatia" : "クロアチア",
    "Haiti" : "ハイチ",
    "Hungary" : "ハンガリー",
    "Indonesia" : "インドネシア",
    "Ireland" : "アイルランド",
    "Israel" : "イスラエル",
    "Isle of Man" : "マン島",
    "India" : "インド",
    "British Indian Ocean Territory" : "イギリス領インド洋地域",
    "Iraq" : "イラク",
    "Iran, Islamic Republic of" : "イラン・イスラム共和国",
    "Iceland" : "アイスランド",
    "Italy" : "イタリア",
    "Jersey" : "ジャージー",
    "Jamaica" : "ジャマイカ",
    "Jordan" : "ヨルダン・ハシミテ王国",
    "Japan" : "日本",
    "Kenya" : "ケニア",
    "Kyrgyzstan" : "キルギス",
    "Cambodia" : "カンボジア",
    "Kiribati" : "キリバス",
    "Comoros" : "コモロ",
    "Saint Kitts and Nevis" : "セントクリストファー・ネイビス",
    "Korea, Democratic People's Republic of" : "朝鮮民主主義人民共和国",
    "Korea, Republic of" : "大韓民国",
    "Kuwait" : "クウェート",
    "Cayman Islands" : "ケイマン諸島",
    "Kazakhstan" : "カザフスタン",
    "Lao People's Democratic Republic" : "ラオス",
    "Lebanon" : "レバノン",
    "Saint Lucia" : "セントルシア",
    "Liechtenstein" : "リヒテンシュタイン",
    "Sri Lanka" : "スリランカ",
    "Liberia" : "リベリア",
    "Lesotho" : "レソト",
    "Lithuania" : "リトアニア",
    "Luxembourg" : "ルクセンブルク",
    "Latvia" : "ラトビア",
    "Libya" : "リビア",
    "Morocco" : "モロッコ",
    "Monaco" : "モナコ",
    "Moldova, Republic of" : "モルドバ共和国",
    "Montenegro" : "モンテネグロ",
    "Saint Martin (French part)" : "セント・マーチン島（フランス領）",
    "Madagascar" : "マダガスカル",
    "Marshall Islands" : "マーシャル諸島",
    "North Macedonia" : "北マケドニア共和国",
    "Mali" : "マリ",
    "Myanmar" : "ミャンマー",
    "Mongolia" : "モンゴル",
    "Macao" : "マカオ",
    "Northern Mariana Islands" : "北マリアナ諸島",
    "Martinique" : "マルティニーク",
    "Mauritania" : "モーリタニア",
    "Montserrat" : "モントセラト",
    "Malta" : "マルタ",
    "Mauritius" : "モーリシャス",
    "Maldives" : "モルディブ",
    "Malawi" : "マラウイ共和国",
    "Mexico" : "メキシコ",
    "Malaysia" : "マレーシア",
    "Mozambique" : "モザンビーク",
    "Namibia" : "ナミビア",
    "New Caledonia" : "ニューカレドニア",
    "Niger" : "ニジェール",
    "Norfolk Island" : "ノーフォーク島",
    "Nigeria" : "ナイジェリア",
    "Nicaragua" : "ニカラグア",
    "Netherlands" : "オランダ",
    "Norway" : "ノルウェー",
    "Nepal" : "ネパール",
    "Nauru" : "ナウル",
    "Niue" : "ニウエ",
    "New Zealand" : "ニュージーランド",
    "Oman" : "オマーン",
    "Panama" : "パナマ",
    "Peru" : "ペルー",
    "French Polynesia" : "フランス領ポリネシア",
    "Papua New Guinea" : "パプアニューギニア",
    "Philippines" : "フィリピン",
    "Pakistan" : "パキスタン",
    "Poland" : "ポーランド",
    "Saint Pierre and Miquelon" : "サンピエール島・ミクロン島",
    "Pitcairn" : "ピトケアン諸島",
    "Puerto Rico" : "プエルトリコ",
    "Palestine, State of" : "パレスチナ",
    "Portugal" : "ポルトガル",
    "Palau" : "パラオ",
    "Paraguay" : "パラグアイ",
    "Qatar" : "カタール",
    "Réunion" : "レユニオン",
    "Romania" : "ルーマニア",
    "Serbia" : "セルビア",
    "Russian Federation" : "ロシア連邦",
    "Rwanda" : "ルワンダ",
    "Saudi Arabia" : "サウジアラビア",
    "Solomon Islands" : "ソロモン諸島",
    "Seychelles" : "セーシェル",
    "Sudan" : "スーダン",
    "Sweden" : "スウェーデン",
    "Singapore" : "シンガポール",
    "Saint Helena, Ascension and Tristan da Cunha" : "セントヘレナ・アセンションおよびトリスタンダクーニャ",
    "Slovenia" : "スロベニア",
    "Svalbard and Jan Mayen" : "スヴァールバル諸島およびヤンマイエン島",
    "Slovakia" : "スロバキア",
    "Sierra Leone" : "シエラレオネ",
    "San Marino" : "サンマリノ",
    "Senegal" : "セネガル",
    "Somalia" : "ソマリア",
    "Suriname" : "スリナム",
    "South Sudan" : "南スーダン",
    "Sao Tome and Principe" : "サントメ・プリンシペ",
    "El Salvador" : "エルサルバドル",
    "Sint Maarten (Dutch part)" : "シント・マールテン（オランダ領）",
    "Syrian Arab Republic" : "シリア・アラブ共和国",
    "Eswatini" : "エスワティニ王国",
    "Turks and Caicos Islands" : "タークス・カイコス諸島",
    "Chad" : "チャド",
    "French Southern Territories" : "フランス領南方・南極地域",
    "Togo" : "トーゴ",
    "Thailand" : "タイ",
    "Tajikistan" : "タジキスタン",
    "Tokelau" : "トケラウ",
    "Timor-Leste" : "東ティモール",
    "Turkmenistan" : "トルクメニスタン",
    "Tunisia" : "チュニジア",
    "Tonga" : "トンガ王国",
    "Turkey" : "トルコ",
    "Trinidad and Tobago" : "トリニダード・トバゴ",
    "Tuvalu" : "ツバル",
    "Taiwan, Province of China" : "台湾中華民国",
    "Tanzania, United Republic of" : "タンザニア",
    "Ukraine" : "ウクライナ",
    "Uganda" : "ウガンダ",
    "United States Minor Outlying Islands" : "合衆国領有小離島",
    "United States of America" : "アメリカ合衆国",
    "Uruguay" : "ウルグアイ",
    "Uzbekistan" : "ウズベキスタン",
    "Holy See" : "バチカン",
    "Saint Vincent and the Grenadines" : "セントビンセント・グレナディーン",
    "Venezuela, Bolivarian Republic of" : "ベネズエラ、ボリバル共和国",
    "Virgin Islands, British" : "英領ヴァージン諸島",
    "Virgin Islands, U.S." : "米バージン諸島",
    "Viet Nam" : "ベトナム",
    "Vanuatu" : "バヌアツ",
    "Wallis and Futuna" : "ウォリス・フツナ",
    "Samoa" : "サモア",
    "Yemen" : "イエメン",
    "Mayotte" : "マヨット",
    "South Africa" : "南アフリカ",
    "Zambia" : "ザンビア",
    "Zimbabwe" : "ジンバブエ",
    "Background blur" : "背景をぼかす",
    "Your web server is not properly set up to deliver `.wasm` files. This is typically an issue with the Nginx configuration. For background blur it needs an adjustment to also deliver `.wasm` files. Compare your Nginx configuration to the recommended configuration in our documentation." : "Webサーバーは、`.wasm`ファイルを配信するように適切に設定されていません。これは通常、Nginx設定に問題があります。背景のぼかしを行うためには、`.wasm`ファイルを配信できるように調整する必要があります。 Nginxの設定をドキュメントの推奨構成と比べてください。",
    "Federation" : "連携",
    "It is highly recommended to configure \"memcache.locking\" when Talk Federation is enabled." : "Talk連携を有効にする場合は、\"memcache.locking\"の構成が必須です。",
    "High-performance backend" : "高性能バックエンド",
    "No High-performance backend configured - Running Nextcloud Talk without the High-performance backend only scales for very small calls (max. 2-3 participants). Please set up the High-performance backend to ensure calls with multiple participants work seamlessly." : "高性能バックエンドが構成されていません - 高性能バックエンドなしでNextcloud Talkを実行すると、非常に小規模な通話 (最大2～3人の参加者)でのみ利用できます。複数の参加者との通話がシームレスに機能するようにするためには高性能バックエンドを設定してください。",
    "Running the High-performance backend \"conversation_cluster\" mode is deprecated and will no longer be supported in the upcoming version. The High-performance backend supports real clustering nowadays which should be used instead." : "高パフォーマンス バックエンドの「conversation_cluster」モードの実行は非推奨となり、次のバージョンではサポートされなくなります。現在、高性能バックエンドはクラスタリングをサポートしているため、それを代わりに使用してください。",
    "Defining multiple High-performance backends is deprecated and will no longer be supported in the upcoming version. Instead a load-balancer should be set up together with clustered signaling servers and configured in the Talk settings." : "複数の高パフォーマンス バックエンドの定義は非推奨となり、次のバージョンではサポートされなくなります。代わりに、ロードバランサーをクラスター化されたシグナリング サーバーと一緒にセットアップし、Talk設定で構成する必要があります。",
    "Error: Cannot connect to server" : "エラー：サーバーに接続できません",
    "Error: Server did not respond with proper JSON" : "エラー：サーバーは適切なJSONで応答しませんでした",
    "Error: Certificate expired" : "エラー: 証明書の有効期限が切れています",
    "Error: System times of Nextcloud server and High-performance backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "エラー: Nextcloudサーバーと高性能バックエンドサーバーのシステム時間が同期していません。両方のサーバーがタイムサーバーに接続されていることを確認するか、手動で時刻を同期してください。",
    "Could not get version" : "バージョンを取得できません",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "エラー: 実行中のバージョン: {version}; このバージョンのTalkと互換性を持たせるには、サーバーの更新が必要です",
    "Error: Server responded with: {error}" : "エラー：サーバーは次の応答を返しました： {error}",
    "Error: Unknown error occurred" : "エラー：不明なエラーが発生しました",
    "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}" : "警告: 実行中のバージョン: {version}; サーバーはこのTalkバージョンの全ての機能をサポートしていません。欠落している機能: {features}",
    "It is highly recommended to configure a memory cache when running Nextcloud Talk with a High-performance backend." : "高性能バックエンドでNextcloud Talkを実行する場合は、メモリキャッシュを構成することを強くお勧めします。",
    "Recording backend" : "レコーディングバックエンド",
    "SIP configuration" : "SIP構成",
    "Invalid date, date format must be YYYY-MM-DD" : "日付が無効です。日付形式はYYYY-MM-DDである必要があります",
    "Conversation not found" : "会話が見つかりません",
    "Path is already shared with this conversation" : "パスはすでにこの会話で共有されています",
    "Chat, video & audio-conferencing using WebRTC" : "WebRTCを使用したチャット、ビデオ、および音声会議",
    "Chat, video & audio-conferencing using WebRTC\n\n* 💬 **Chat** Nextcloud Talk comes with a simple text chat, allowing you to share or upload files from your Nextcloud Files app or local device and mention other participants.\n* 👥 **Private, group, public and password protected calls!** Invite someone, a whole group or send a public link to invite to a call.\n* 🌐 **Federated chats** Chat with other Nextcloud users on their servers\n* 💻 **Screen sharing!** Share your screen with the participants of your call.\n* 🚀 **Integration with other Nextcloud apps** like Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck, and many more.\n* 🌉 **Sync with other chat solutions** With [Matterbridge](https://github.com/42wim/matterbridge/) being integrated in Talk, you can easily sync a lot of other chat solutions to Nextcloud Talk and vice-versa." : "WebRTC を使用したチャット、ビデオ、音声会議\n\n* 💬 **チャット** Nextcloud Talkには簡単なテキスト チャットが付属しており、Nextcloud Filesアプリまたはローカル デバイスからファイルを共有またはアップロードし、他の参加者に通知することができます。\n* 👥 **プライベート、グループ、パブリック、およびパスワードで保護された通話!** 特定の誰かやグループ全体を招待したり、公開リンクの送信により通話へ招待します。\n* 🌐 **フェデレーション チャット** 他のNextcloudサーバー上のユーザーとチャットできます。\n* 💻 **画面共有!** 通話の参加者に画面を共有します。\n* 🚀 **ファイル、カレンダー、ユーザー ステータス、ダッシュボード、フロー、マップ、スマート ピッカー、連絡先、デッキなどの他のNextcloudアプリと統合** \n* 🌉 **他のチャット ソリューションと同期** [Matterbridge](https://github.com/42wim/matterbridge/) がTalkに統合されているため、他の多くのチャット ソリューションをNextcloud Talkに簡単に同期したり、その逆を行うことができます。",
    "Leave call" : "通話終了",
    "Navigating away from the page will leave the call in {conversation}" : "ページから離れると {conversation} の中に呼び出しが残ります。",
    "Stay in call" : "通話を続ける",
    "Duplicate session" : "セッションの重複",
    "Discuss this file" : "このファイルについて話し合う",
    "Loading …" : "読み込み中…",
    "Share this file with others to discuss it" : "このファイルを他の人と共有して話し合う",
    "Join conversation" : "会話に参加",
    "Share this file" : "このファイルを共有する",
    "Error occurred when joining the conversation" : "会話に参加する際にエラーが発生しました",
    "This conversation is password-protected." : "この会話はパスワードで保護されています。",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "あなたのIPから複数の無効なパスワード試行が検出されました。したがって、次の試行は最大30秒間抑制されます。",
    "The password is wrong. Try again." : "パスワードが違います。再入力してください",
    "Password" : "パスワード",
    "Submit" : "送信",
    "Error requesting the password." : "パスワードのリクエスト中にエラーが発生しました。",
    "Request password" : "パスワードを入力",
    "This conversation has ended" : "会話は終了しました",
    "Close Talk sidebar" : "Talk サイドバーを閉じる",
    "Open Talk sidebar" : "Talk サイドバーを開く",
    "Everyone" : "すべてのユーザー",
    "Users and moderators" : "ユーザーとモデレーター",
    "Moderators only" : "モデレータ専用",
    "Disable calls" : "通話を無効にする",
    "Save changes" : "変更を保存",
    "Saving …" : "保存中...",
    "Saved!" : "保存完了！",
    "Limit to groups" : "グループに制限する",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "最低1つグループが選択されている場合、グループにリストされたユーザーのみが会話に参加できます。",
    "Guests can still join public conversations." : "ゲストはまだ公開会話に参加できます。",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "トークが使えなくなったユーザーも、以前の会話の参加者としてリストアップされ、チャットメッセージも残されています。",
    "Limit using Talk" : "トークの使用を制限",
    "Limit creating a public and group conversation" : "公開およびグループ会話の作成を制限する",
    "Limit creating conversations" : "会話の作成を制限する",
    "Limit starting a call" : "通話の開始を制限する",
    "Limit starting calls" : "通話の開始を制限する",
    "When a call has started, everyone with access to the conversation can join the call." : "通話が開始されると、会話にアクセスできる全員が通話に参加できます。",
    "The following bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "このサーバーには次のボットがインストールされています。ドキュメントには、{linkstart1}独自のボットを作成する方法{linkend}や、サーバーで有効にする{linkstart2}ボットのリスト{linkend}の詳細が見つかります。",
    "No bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "このサーバーにはボットがインストールされていません。ドキュメントには、{linkstart1}独自のボットを作成する方法{linkend}や、サーバーで有効にする{linkstart2}ボットのリスト{linkend}の詳細が見つかります。",
    "Description is not provided" : "概要は提供されていません",
    "Locked for moderators" : "モデレーターのためにロックされた",
    "Enabled" : "有効",
    "Disabled" : "無効",
    "Bots settings" : "ボットの設定",
    "State" : "状態",
    "Name" : "名前",
    "Last error" : "最後のエラー",
    "Total errors count" : "エラーの総数",
    "Find more bots" : "他のボットを探す",
    "Trusted servers can be configured at {linkstart}Sharing settings page{linkend}." : "信頼できるサーバーは、{linkstart}共有設定ページ{linkend}で設定することができます。",
    "Beta" : "ベータ",
    "Enable Federation in Talk app" : "アプリ内でTalkの連携を有効化してください。",
    "Permissions" : "アクセス権限",
    "Allow users to be invited to federated conversations" : "ユーザーを招待してフェデレーション会話を許可する",
    "Only allow to federate with trusted servers" : "信頼できるサーバーにのみ連携を許可する",
    "When at least one group is selected, only people of the listed groups can invite federated users to conversations." : "最低1つグループが選択されている場合、グループにリストされたユーザーのみが会話にフェデレーテッドユーザーを招待できます。",
    "Select groups …" : "グループを選択 ...",
    "All messages" : "全てのメッセージ",
    "@-mentions only" : "@で直接会話",
    "Off" : "オフ",
    "General settings" : "一般設定",
    "Default notification settings" : "デフォルトの通知設定",
    "Default group notification" : "デフォルトのグループ通知",
    "Default group notification for new groups" : "新しいグループのデフォルトのグループ通知",
    "Integration into other apps" : "他のアプリへの統合",
    "Allow conversations on files" : "ファイルでの会話を許可する",
    "Allow conversations on public shares for files" : "公開共有ファイルでの会話を許可する",
    "Enable encryption" : "暗号化を有効にする",
    "End-to-end encrypted calls with a configured SIP bridge require a newer version of the High-performance backend and SIP bridge." : "構成されたSIPブリッジでのエンドツーエンドの暗号化通話には、新しいバージョンの高性能バックエンドとSIPブリッジが必要です。",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "上のボタンをクリックすると、フォーム内の情報がStruktur AGのサーバーに送信されます。詳細については、{linkstart}spreed.eu{linkend}をご覧ください。",
    "Pending" : "保留中",
    "Error" : "エラー",
    "Blocked" : "ブロックされた",
    "Active" : "アクティブ化",
    "Expired" : "有効期限切れ",
    "Never" : "なし",
    "The trial could not be requested. Please try again later." : "トライアルを要求できませんでした。後ほどもう一度お試しください。",
    "The account could not be deleted. Please try again later." : "アカウントを削除できませんでした。後ほどもう一度お試しください。",
    "Hosted High-performance backend" : "ホストされた高性能バックエンド",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "当社のパートナーであるStruktur AGは、ホストされたシグナリングサーバーをリクエストできるサービスを提供しています。以下のフォームに必要事項を入力するだけで、Nextcloudがリクエストを行います。サーバーの設定が完了すると、認証情報が自動的に入力されます。これにより、既存のシグナリングサーバーの設定が上書きされます。",
    "If your high-performance backend account includes STUN and/or TURN functionality, the settings will be updated accordingly." : "高性能バックエンド アカウントにSTUNおよび/またはTURN機能が含まれている場合、設定はそれに応じて更新されます。",
    "URL of this Nextcloud instance" : "このNextcloudインスタンスのURL",
    "Full name of the user requesting the trial" : "トライアルを要求しているユーザーのフルネーム",
    "Email of the user" : "ユーザーのメールアドレス",
    "Language" : "言語",
    "Country" : "国名",
    "Request signaling server trial" : "シグナリングサーバーへのトライアル要求",
    "You can see the current status of your hosted signaling server in the following table." : "次の表で、ホストされているシグナリング サーバーの現在の状態を確認できます。",
    "Status" : "ステータス",
    "Created at" : "作成:",
    "Expires at" : "有効期限:",
    "Limits" : "制限",
    "Yes" : "はい",
    "No" : "いいえ",
    "Delete the signaling server account" : "シグナリングサーバーのアカウントを削除",
    "_%n user_::_%n users_" : ["%nユーザー"],
    "Installed version: {version}" : "インストールされているバージョン: {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "Matterbridgeをインストールすることで、Nextcloud Talkをほかのサービスにリンクできます。詳細は、{linkstart1}GitHub ページ{linkend}をご確認ください。アプリのダウンロードとインストールには時間がかかる場合があります。タイムアウトした場合は、{linkstart2}Nextcloud アプリストア{linkend}から手動でインストールしてください。",
    "Matterbridge binary was not found or couldn't be executed." : "Matterbridgeバイナリが見つからなかったか、実行できませんでした。",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "設定を使用して、Matterbridgeバイナリへのパスを手動で設定することもできます。詳細については、{linkstart} Matterbridge統合ドキュメント{linkend}を確認してください。",
    "Downloading …" : "ダウンロード中…",
    "Install Talk Matterbridge" : "Talk Matterbridgeをインストールします",
    "An error occurred while installing the Matterbridge app" : "Matterbridgeアプリのインストール中にエラーが発生しました",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "Talk Matterbridgeのインストール中にエラーが発生しました。手動でインストールしてください。",
    "Failed to execute Matterbridge binary." : "Matterbridgeバイナリを実行できませんでした。",
    "Matterbridge integration" : "Matterbridge連携",
    "Enable Matterbridge integration" : "Matterbridge連携を有効にする",
    "Status: Checking connection" : "ステータス：接続を確認しています",
    "OK: Running version: {version}" : "OK: 実行中のバージョン: {version}",
    "Error: Server seems to be a Signaling server" : "エラー: サーバーはシグナリングサーバーのようです",
    "Error: System times of Nextcloud server and Recording backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "エラー: Nextcloud サーバーと録画バックエンドサーバーのシステム時刻が同期していません。両方のサーバーがタイムサーバーに接続されていることを確認するか、手動で時刻を同期してください。",
    "Recording backend URL" : "レコーディングバックエンドURL",
    "Validate SSL certificate" : "SSL証明書を検証する",
    "Delete this server" : "このサーバーを削除",
    "Test this server" : "このサーバーをテスト",
    "Disabled for all calls" : "全ての通話で無効化されました",
    "Enabled for all calls" : "全ての通話で有効化されました",
    "Configurable on conversation level by moderators" : "モデレーターにより会話レベルで設定可能",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "PHPの設定 \"upload_max_filesize\" または \"post_max_size\" では、{maxUpload} までのファイルのアップロードが許可されます。",
    "Recording backend settings saved" : "レコーディングバックエンドの設定が保存されました",
    "Moderators will be allowed to enable consent on conversation level. The consent to be recorded will be required for each participant before joining every call in this conversation." : "会話モデレーターは、会話レベルで同意を有効にすることができます。この会話に参加する前に、各参加者は録音されることへの同意が必要となります。",
    "The consent to be recorded will be required for each participant before joining every call." : "毎回通話に参加する前に、録音されることへの同意が各参加者は必要となります。",
    "The consent to be recorded is not required." : "録画されることへの同意は必要ありません。",
    "Recording backend configuration is only possible with a High-performance backend." : "録画バックエンドは、高パフォーマンスのバックエンドでのみ可能です。",
    "Add a new recording backend server" : "新しいレコーディングバックエンドサーバーを追加する",
    "Shared secret" : "共有秘密鍵",
    "Recording consent" : "レコーディングの同意",
    "SIP configuration saved!" : "SIP 設定を保存しました！",
    "SIP configuration is only possible with a High-performance backend." : "SIP構成は、高性能バックエンドでのみ可能です。",
    "Enable SIP Dial-out option" : "SIPダイヤル発信オプションを有効にする",
    "Signaling server needs to be updated to supported SIP Dial-out feature." : "SIPダイヤル発信機能をサポートするように、シグナリングサーバーを更新する必要があります。",
    "Restrict SIP configuration" : "SIP構成を制限する",
    "Enable SIP configuration" : "SIP構成を有効にする",
    "Only users of the following groups can enable SIP in conversations they moderate" : "次のグループのユーザーのみが、モデレートする会話でSIPを有効にできます",
    "Phone number (Country)" : "電話番号 (国番号)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "この情報は招待メールで送信されるだけでなく、サイドバーにすべての参加者に表示されます。",
    "High-performance backend URL" : "高性能バックエンドURL",
    "High-performance backend settings saved" : "ハイパフォーマンスバックエンドの設定が保存されました",
    "Please note that in calls with more than 2 participants without the High-performance backend, participants will most likely experience connectivity issues and cause high load on participating devices." : "高性能バックエンドを使用しない3人以上の参加者との通話では、参加者に接続の問題が発生し、参加デバイスに高負荷がかかる可能性が高いことに注意してください。",
    "Install the High-performance backend to ensure calls with multiple participants work seamlessly." : "複数の参加者との通話がシームレスに機能するようにするには高性能バックエンドをインストールしてください。",
    "The High-performance backend is required for calls and conversations with multiple participants. Without the backend, all participants have to upload their own video individually for each other participant, which will most likely cause connectivity issues and a high load on participating devices." : "複数参加者の通話や会話には高性能バックエンドが必要です。バックエンドがない場合、参加者全員が他の参加者全員に対して一対一で動画データを送信する必要があり、接続問題や参加デバイスの高負荷を引き起こす可能性が非常に高くなります。",
    "It is highly recommended to set up a distributed cache when using Nextcloud Talk with a High-performance backend." : "Nextcloud Talkを高性能バックエンドで使用する場合は、分散キャッシュをセットアップすることを強くお勧めします。",
    "Add High-performance backend server" : "高性能バックエンドを追加",
    "STUN server URL" : "STUN server URL",
    "The server address is invalid" : "サーバーアドレスは無効です",
    "STUN settings saved" : "STUN 設定を保存しました",
    "STUN servers" : "STUNサーバー",
    "A STUN server is used to determine the public IP address of participants behind a router." : "STUNサーバーは、ルーターを介した参加者のパブリックIPアドレスを決定するために使用されます。",
    "Add a new STUN server" : "新しいSTUN サーバーを追加",
    "{schema} scheme must be used with a domain" : "{schema} スキームはドメインで使用する必要があります",
    "{option1} and {option2}" : "{option1} と {option2}",
    "{option} only" : "{option} のみ",
    "OK: Successful ICE candidates returned by the TURN server" : "成功: TURNサーバからICE候補への返答がありました",
    "Error: No working ICE candidates returned by the TURN server" : "エラー: TURNサーバからICE候補への返答がありません",
    "Testing whether the TURN server returns ICE candidates" : "TURNサーバーがICE候補を返すかどうかのテスト",
    "TURN server schemes" : "TURNサーバースキーム",
    "TURN server URL" : "TURN server URL",
    "TURN server secret" : "TURNサーバーシークレット",
    "TURN server protocols" : "TURNサーバープロトコル",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "TURNサーバーは、ファイアウォールの内側で参加者からのトラフィックをプロキシするために使用されます。個々の参加者が他の参加者に接続できない場合は、TURNサーバーが必要になる可能性があります。セットアップ手順については、{linkstart}このドキュメント{linkend}を参照してください。",
    "TURN settings saved" : "TURN 設定を保存しました",
    "TURN servers" : "TURNサーバー",
    "Add a new TURN server" : "新しいTURN サーバーを追加",
    "Failed" : "失敗",
    "OK" : "OK",
    "Checking …" : "チェック中…",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "失敗: WebAssemblyが無効になっているか、このブラウザーではサポートされていません。チェックを実施するには、WebAssemblyを有効にするか、サポートしているブラウザーをご利用ください。",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "失敗: \".wasm\" と \".tflite\" ファイルは、Webブラウザーにより正しく返却されませんでした。 Talkに関するドキュメントの\"システム要件\"をご確認ください。",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "OK: \".wasm\" と \".tflite\" ファイルがWebブラウザーにより正しく返却されました。",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "PHP と Apache の設定に互換性がないようです。PHP は MPM_PREFORK モジュールでのみ使用可能であり、PHP-FPM は MPM_EVENT モジュールでのみ使用可能であることに注意してください。",
    "Web server setup checks" : "Webサーバーセットアップチェック",
    "Files required for virtual background can be loaded" : "バーチャル背景に必要なファイルを読み込むことができます",
    "Federated user" : "フェデレーションユーザー",
    "Assign participants to rooms" : "参加者をルームに割り当てる",
    "Configure breakout rooms" : "子会議室の設定",
    "Number of breakout rooms" : "子会議室数",
    "You can create from 1 to 20 breakout rooms." : "1 から 20 の子会議室を作成することができます。",
    "Assignment method" : "割り当て方法",
    "Automatically assign participants" : "参加者を自動的に割り当てる",
    "Manually assign participants" : "参加者を手動で割り当てる",
    "Allow participants to choose" : "参加者に選択することを許可する",
    "Create rooms" : "部屋を作成する",
    "Confirm" : "承認",
    "Create breakout rooms" : "子会議室を作成する",
    "Reset" : "リセット",
    "Delete breakout rooms" : "子会議室を削除する",
    "Room {roomNumber}" : "ルーム {roomNumber}",
    "Current breakout rooms and settings will be lost" : "現在の子会議室と設定は失われます",
    "Cancel" : "キャンセル",
    "Unassigned participants" : "参加者未割り当て",
    "Back" : "戻る",
    "Assign" : "割り当てる",
    "Add participant \"{user}\"" : "参加者 \"{user}\" を追加",
    "Now" : "現在",
    "Meeting created" : "会議を作成しました",
    "Upcoming meetings" : "今後の会議",
    "No upcoming meetings" : "今後の会議はありません",
    "Schedule a meeting" : "会議を予約する",
    "Meeting title" : "会議名",
    "From" : "差出人",
    "To" : "宛先",
    "Calendar" : "カレンダー",
    "Attendees" : "参加者",
    "No other participants to send invitations to." : "他に招待状を送信できる参加者はいません。",
    "Save" : "保存",
    "Search participants" : "参加者を探す",
    "No results" : "該当なし",
    "Done" : "完了",
    "Exit full screen (F)" : "全画面終了 (F)",
    "Full screen (F)" : "全画面 (F)",
    "Speaker view" : "スピーカービュー",
    "Grid view" : "グリッド表示",
    "This conversation is read-only" : "この会話は読み取り専用です",
    "Reload" : "再読み込み",
    "{nickName} raised their hand." : "{nickName} が挙手しました",
    "A participant raised their hand." : "参加者が挙手しました",
    "Collapse stripe" : "スレッドを折りたたむ",
    "Expand stripe" : "スレッドを展開する",
    "Previous page of videos" : "動画の前ページ",
    "Next page of videos" : "動画の次ページ",
    "Connecting …" : "接続中 …",
    "Calling …" : "接続中...",
    "Waiting for {user} to join the call" : "{user} が通話に参加するのを待っています",
    "Waiting for others to join the call …" : "参加を待っています …",
    "You can invite others in the participant tab of the sidebar" : "サイドバーの参加者タブで他のユーザーを招待できます",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "サイドバーの参加者タブかこのリンクを共有して他のユーザーを招待できます。",
    "Share this link to invite others!" : "このリンクを共有して他の人を招待します。",
    "Copy link" : "リンクをコピー",
    "You are not allowed to enable audio" : "音声を有効にできません",
    "No audio. Click to select device" : "音声がありません。デバイスを選択するにはクリックしてください。",
    "Mute audio" : "音声なし",
    "Mute audio (M)" : "音声ミュート (m)",
    "Unmute audio" : "ミュート解除",
    "Unmute audio (M)" : "音声ミュート解除 (m)",
    "None" : "なし",
    "Check devices" : "デバイスを確認",
    "Access to camera was denied" : "カメラへのアクセスが拒否されました",
    "Error while accessing camera: It is likely in use by another program" : "カメラへのアクセス時にエラー: その他のアプリケーションが利用中の可能性があります",
    "Error while accessing camera" : "カメラにアクセス時にエラーが発生",
    "You have been muted by a moderator" : "あなたはモデレーターによってミュートされています",
    "You are not allowed to enable video" : "ビデオを有効にできません",
    "No video. Click to select device" : "映像がありません。デバイスを選択するにはクリックしてください。",
    "Disable video" : "映像なし",
    "Disable video (V)" : "ビデオなし(V)",
    "Enable video" : "動画を有効にする",
    "Enable video (V)" : "ビデオあり(V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "ビデオを有効にする - 初めてビデオを有効にする場合、接続が一時的に中断されます",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "ビデオを有効にする (V) - ビデオを最初に有効にすると、接続が一時的に中断されます。",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "ビデオを有効にします。初回ビデオを有効時、接続が一時的に中断されます。",
    "Show presenter" : "プレゼンターを表示する",
    "You" : "あなた",
    "Mute" : "ミュート",
    "Muted" : "ミュート",
    "Show screen" : "画面を表示",
    "Stop following" : "フォローの停止",
    "Connection could not be established …" : "接続を確立できませんでした...",
    "Connection was lost and could not be re-established …" : "接続が失われ、接続を再確立できませんでした...",
    "Connection could not be established. Trying again …" : "接続が確立できませんでした。再試行しています...",
    "Connection lost. Trying to reconnect …" : "接続が失われました。再接続しています...",
    "Connection problems …" : "接続で問題が発生しました...",
    "Collapse" : "折りたたむ",
    "Expand" : "展開",
    "You need to be logged in to upload files" : "ファイルをアップロードするにはログインが必要です",
    "Drop your files to upload" : "アップロードするファイルをドロップしてください",
    "Conversation messages" : "会話メッセージ",
    "Scroll to bottom" : "下にスクロール",
    "Post message" : "メッセージを送信",
    "Federated conversation" : "フェデレート会話",
    "Public conversation" : "公開会話",
    "Favorite" : "お気に入り",
    "Banned users" : "禁止されたユーザー",
    "Date:" : "日時:",
    "Note:" : "注意：",
    "Hide details" : "詳細を隠す",
    "Show details" : "詳細を見る",
    "Error while updating conversation name" : "会話名の変更中にエラーが発生しました",
    "Error while updating conversation description" : "会話の詳細の更新中にエラーが発生しました",
    "Enter a name for this conversation" : "この会話名を設定してください。",
    "Edit conversation name" : "会話名を変更",
    "Edit conversation description" : "会話の詳細を編集する",
    "Enter a description for this conversation" : "この会話の説明を入力",
    "Picture" : "写真",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "この会話では以下のボットを有効にすることができます。このサーバーにさらにボットをインストールするには、管理者にお問い合わせください。",
    "No bots are installed on this server. Reach out to your administration to get bots installed on this server." : "このサーバーにはボットがインストールされていません。このサーバーにボットをインストールするには、管理者にお問い合わせください。",
    "Disable" : "無効",
    "Enable" : "有効にする",
    "Breakout rooms" : "ブレークアウト・ルーム(子会議室)",
    "Manage breakout rooms" : "子会議室を管理する",
    "Set up breakout rooms for this conversation" : "この会話の子会議室を設定する",
    "Please select a valid PNG or JPG file" : "PNG もしくは、JPGファイルを選択してください",
    "Choose your conversation picture" : "あなたの会話画像を選択する",
    "Choose" : "選択",
    "Error setting conversation picture" : "会話画像設定エラー",
    "Could not set the conversation picture: {error}" : "会話画像を設定できませんでした: {error}",
    "Error cropping conversation picture" : "会話画像の切り抜きエラー",
    "Error removing conversation picture" : "会話画像の削除エラー",
    "Set emoji as conversation picture" : "絵文字を会話画像に設定する",
    "Set background color for conversation picture" : "会話画像の背景色を設定する",
    "Upload conversation picture" : "会話画像をアップロードする",
    "Choose conversation picture from files" : "このチャットの画像をファイルから選択",
    "Remove conversation picture" : "このチャットの画像を削除",
    "The file must be a PNG or JPG" : "ファイルは PNG または JPG でなければなりません",
    "Set picture" : "画像を設定",
    "Default permissions modified for {conversationName}" : "{conversationName} の初期設定の権限は変更されています",
    "Could not modify default permissions for {conversationName}" : "{conversationName}のデフォルト権限を変更できません",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "この会話での初期設定のパーミッションを編集できます。これらの設定はモデレーターには影響しません。",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "このセクションでパーミッションが変更されるたびに、以前に個々の参加者に割り当てられたカスタムパーミッションは失われます。",
    "All permissions" : "すべての権限",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "参加者は、通話の開始、参加、音声とビデオの有効、画面共有の権限を持っています。",
    "Restricted" : "制限付き",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "参加者は、通話の参加は可能ですが、音声、ビデオ、画面共有は、モデレーターが個別に権限を付与するまで無効になっています。",
    "Advanced permissions" : "詳細な権限",
    "Edit permissions" : "権限を編集",
    "Conversation settings" : "会話設定",
    "Basic Info" : "基本情報",
    "Personal" : "個人",
    "Moderation" : "モデレーション",
    "Setup overview" : "セットアップの概要",
    "Live transcription" : "音声の文字起こし",
    "Breakout Rooms" : "ブレークアウト・ルーム(子会議室)",
    "Matterbridge" : "Matterbridge",
    "Bots" : "ボット",
    "Danger zone" : "危険区域",
    "Archive conversation" : "会話をアーカイブ",
    "You can archive this conversation instead." : "代わりにこの会話をアーカイブすることもできます。",
    "Leave conversation" : "会話を離れる",
    "You need to promote a new moderator before you can leave the conversation" : "会話から離れる前に、新しいモデレーターを昇格させる必要があります",
    "Delete conversation" : "会話を削除",
    "Do you really want to delete \"{displayName}\"?" : "本当に「{displayName}」を削除しますか？",
    "Error while deleting conversation" : "会話の削除中にエラーが発生しました",
    "Delete all chat messages" : "チャットメッセージをすべて削除",
    "Do you really want to delete all messages in \"{displayName}\"?" : "\"{displayName}\" のすべてのメッセージを削除しても本当によろしいですか？",
    "Error while clearing chat history" : "チャット履歴のクリア中にエラーが発生しました",
    "Be careful, these actions cannot be undone." : "これらのアクションは元に戻せないので注意してください。",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "会話から退出したら、クローズな会話に再び参加するには、招待が必要です。オープンな会話はいつでも再参加できます。",
    "Permanently delete this conversation." : "この会話を完全に削除する",
    "Delete chat messages" : "メッセージを削除する",
    "Permanently delete all the messages in this conversation." : "この会話のすべてのメッセージを完全に削除する",
    "Custom expiration time" : "カスタム有効期限",
    "Message expiration disabled" : "メッセージの有効期限は無効",
    "Message expiration set: {duration}" : "メッセージの有効期限を設定します: {duration}",
    "Error when trying to set message expiration" : "メッセージの有効期限を設定しようとした際のエラー",
    "Message expiration" : "メッセージの有効期限",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "チャットメッセージは、一定時間経過後に期限切れにすることができます。注意: チャットで共有されたファイルは、ファイル所有者は削除されませんが、会話では共有されなくなります。",
    "Set message expiration" : "メッセージの有効期限を設定する",
    "Current message expiration" : "現在のメッセージの有効期限",
    "Password copied to clipboard" : "パスワードをクリップボードにコピーしました",
    "Password could not be copied" : "パスワードをコピーできませんでした",
    "Guest access" : "ゲスト参加",
    "Allow guests to join this conversation via link" : "リンク経由でのこの会話へのゲスト参加を許可",
    "Password protection" : "パスワード保護",
    "Set a password" : "パスワードを設定",
    "Change password" : "パスワードを変更",
    "Enter new password" : "新しいパスワードを入力",
    "Save password" : "パスードを保存",
    "Copy password" : "パスワードをコピー",
    "Guests are allowed to join this conversation via link" : "ゲストはリンクを介してこの会話に参加することが許可されています",
    "Guests are not allowed to join this conversation" : "ゲストはこの会話に参加することは許可されていません",
    "Resend invitations" : "招待を再送",
    "This conversation is open to both registered users and users created with the Guests app" : "この会話は、登録ユーザーとGuestsアプリで作成されたユーザーの両方に開かれています",
    "This conversation is open to registered users" : "この会話は登録ユーザーに開かれています",
    "This conversation is limited to the current participants" : "この会話は現在の参加者に制限されています",
    "You opened the conversation to both registered users and users created with the Guests app" : "登録ユーザーとGuestsアプリで作成したユーザーの両方に会話を公開しました",
    "Error occurred when opening or limiting the conversation" : "会話を開いたり制限したりするときにエラーが発生しました",
    "Open conversation to registered users, showing it in search results" : "登録ユーザーに会話を公開、検索結果に表示します",
    "Also open to users created with the Guests app" : "ゲストアプリで作成されたユーザーも開くことができます",
    "Open conversation" : "オープンな会話",
    "Set language spoken in calls" : "通話時の言語を設定する",
    "Languages could not be loaded" : "言語を読み込めませんでした",
    "Loading languages …" : "言語を読み込んでいます ...",
    "Invalid language" : "無効な言語",
    "Default language (English)" : "デフォルト言語（英語）",
    "Live transcription language set: {languageName}" : "ライブトランスクリプション言語セット:{languageName}",
    "Start time: {date}" : "開始時刻: {date}",
    "Start time has been updated" : "開始時間が更新されました",
    "Error occurred while updating start time" : "開始時刻の更新中にエラーが発生しました",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "ロビーを有効にすると、進行中の通話から非モデレーターが削除されます。",
    "Enable lobby, restricting the conversation to moderators" : "ロビーを有効にし、会話をモデレーターに制限します",
    "Meeting start time" : "会議の開始時間",
    "Start time (optional)" : "開始時間（オプション）",
    "Import email participants" : "メール参加者をインポート",
    "You can import a list of email participants from a CSV file." : "CSVファイルで参加者のメールアドレスリストをインポートできます。",
    "Poll drafts" : "アンケートの草稿",
    "Browse poll drafts" : "アンケート草稿を閲覧",
    "Error occurred when locking the conversation" : "会話のロック中にエラーが発生しました",
    "Error occurred when unlocking the conversation" : "会話のロックを解除するときにエラーが発生しました",
    "Lock conversation" : "会話をロック",
    "This will also terminate the ongoing call." : "これにより、進行中の通話も終了します。",
    "Lock the conversation to prevent anyone to post messages or start calls" : "会話をロックして、誰かがメッセージを投稿したり通話を開始したりできないようにします。",
    "Edit" : "編集",
    "More information" : "詳細情報",
    "Delete" : "削除",
    "Add new bridged channel to current conversation" : "現在の会話に新しいブリッジチャネルを追加する",
    "unknown state" : "状態が不明",
    "running" : "実行中",
    "not running, check Matterbridge log" : "未稼働です。Matterbridgeログを確認してください",
    "not running" : "未稼働",
    "Bridge saved" : "ブリッジが保存されました",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "Matterbridgeを使用すると、さまざまなインスタントメッセージングシステムからチャネルを橋渡しできます。",
    "More info on Matterbridge" : "Matterbridgeの詳細",
    "Messaging systems" : "メッセージングシステム",
    "Enable bridge" : "ブリッジを有効にする",
    "Show Matterbridge log" : "Matterbridgeログを表示する",
    "Log content" : "ログ情報",
    "Only moderators are allowed to mention @all" : "@allにメンションできるのはモデレーターのみです",
    "All participants are allowed to mention @all" : "すべての参加者が@allにメンションできます。",
    "Participants are now allowed to mention @all." : "参加者は@allにメンションできるようになりました。",
    "Mentioning @all has been limited to moderators." : "@allのメンションはモデレーターのみに限定されています。",
    "Allow participants to mention @all" : "参加者が@allにメンションできるようにします",
    "Mention permissions" : "メンション権限",
    "Notifications" : "通知",
    "Notify about calls in this conversation" : "この会話で呼び出し時に通知する",
    "Important conversation" : "重要な会議",
    "Sensitive conversation" : "プライベートな会話",
    "Message preview will be disabled in conversation list and notifications" : "会話リストと通知ではメッセージのプレビューが無効になります",
    "Recording consent is required for calls in this conversation" : "レコーディングの同意は、この会話で必要です",
    "Recording consent is not required for calls in this conversation" : "レコーディングの同意は、この会話で必要ではありません",
    "Recording consent requirement was updated" : "レコーディングの同意要件は更新されました",
    "Error occurred while updating recording consent" : "レコーディングの同意を更新する際にエラーが発生しました",
    "Recording Consent" : "レコーディングの同意",
    "Recording consent cannot be changed once a call or breakout session has started." : "レコーディングの同意は、通話またはブレイクアウトセッションが開始した後に変更することはできません。",
    "Require recording consent before joining call in this conversation" : "この会話に参加する前に、レコーディングの同意が必要です。",
    "Recording consent is required for all calls" : "全ての通話にはレコーディングの同意が必要です",
    "SIP dial-in is now possible without PIN requirement" : "SIPダイアルインが、PINコードなしで可能となります",
    "SIP dial-in is now enabled" : "SIPダイヤルインが有効になりました",
    "SIP dial-in is now disabled" : "SIPダイヤルインが無効になりました",
    "Error occurred when enabling SIP dial-in" : "SIPダイヤルインを有効にするときにエラーが発生しました",
    "Error occurred when disabling SIP dial-in" : "SIPダイヤルインを無効にするときにエラーが発生しました",
    "Phone and SIP dial-in" : "電話とSIP 着信",
    "Enable phone and SIP dial-in" : "電話とSIP 着信を有効にする",
    "Allow to dial-in without a PIN" : "PINコードなしでダイヤルインを許可する",
    "Ongoing" : "進行中",
    "View attachment" : "添付ファイルを見る",
    "Join" : "参加",
    "View conversation" : "会話を表示",
    "View event on Calendar" : "カレンダーでイベントを表示",
    "Error while creating the conversation" : "会話の作成中にエラーが発生しました",
    "Hello, {displayName}" : "こんにちは、{displayName} さん",
    "Start meeting now" : "今すぐ会議を始める",
    "Give your meeting a title" : "会議にタイトルをつける",
    "Create and copy link" : "リンクを作成してコピー",
    "Create a new conversation" : "新しい会話を作成する",
    "Join open conversations" : "オープンな会話に参加する",
    "Call a phone number" : "電話番号にかける",
    "Scroll backward" : "後方にスクロール",
    "Scroll forward" : "前方にスクロール",
    "Schedule meetings" : "会議を予約",
    "You don't have any upcoming meetings" : "今後の会議はありません",
    "Open calendar" : "カレンダーを開く",
    "Unread mentions" : "未読の返信",
    "Messages where you were mentioned will show up here. You can mention people by typing @ followed by their name" : "あなたがメンションされたメッセージはここに表示されます。@に続けて相手の名前を入力すると、メンションできます。",
    "Upcoming reminders" : "今後のリマインダー",
    "Message reminders" : "メッセージのリマインダー",
    "Set a reminder on a message to be notified" : "チャットメッセージにリマインダーを設定すると後で再度通知されるようにできるようになりました",
    "Start a group conversation" : "グループ会話を始める",
    "Create conversation" : "会話を作成",
    "Enter your name" : "あなたの名前を入力",
    "Submit name and join" : "名前を送信して参加する",
    "Do you already have an account?" : "すでにアカウントをお持ちですか?",
    "Log in" : "ログイン",
    "Uploaded file is verified" : "アップロードされたファイルは検証済みです",
    "An error occurred while calling a phone number" : "電話番号への発信中にエラーが発生しました",
    "Phone number could not be called: {error}" : "電話番号に発信できませんでした:  {error}",
    "Phone number could not be called" : "電話番号に発信できませんでした",
    "Search participants or phone numbers" : "参加者または電話番号の検索",
    "Creating the conversation …" : "会話を作成しています...",
    "Mark as read" : "既読にする",
    "Mark as unread" : "未読にする",
    "Remove from favorites" : "お気に入りから削除",
    "Add to favorites" : "お気に入りに追加",
    "Ignore \"Do not disturb\"" : "「邪魔しないでください」を無視する",
    "You need to promote a new moderator before you can leave the conversation." : "会話を終了する前に、新しいモデレータを昇格する必要があります。",
    "New tag" : "新しいタグ",
    "Tag name" : "タグの名前",
    "Conversation actions" : "会話アクション",
    "Tags" : "タグ",
    "Notify about calls" : "着信について通知",
    "Hide message text" : "メッセージテキストを非表示",
    "Rename tag" : "タグ名を変更",
    "Delete tag" : "タグを削除",
    "Move up" : "上に移動",
    "Move down" : "下に移動",
    "Pending invitations" : "保留中の招待",
    "From {user} at {remoteServer}" : "{remoteServer} からの {user} ",
    "Decline invitation" : "招待を拒否",
    "Accept invitation" : "招待を承諾",
    "No pending invitations" : "保留中の招待はありません",
    "Home" : "ホーム",
    "Unread" : "未読",
    "Alphabetically" : "アルファベット順",
    "No matches found" : "一致するものが見つかりません。",
    "No conversations found" : "会話が見つかりません",
    "You have no unread mentions." : "未読のメンションはありません。",
    "You have no unread messages." : "未読のメッセージはありません。",
    "An error occurred while performing the search" : "検索中にエラーが発生しました",
    "Conversation list" : "会話リスト",
    "Unread messages" : "未読のメッセージ",
    "Clear filters" : "フィルターをクリア",
    "New personal note" : "新しい個人的なメモ",
    "Threads" : "スレッド",
    "Clear filter" : "フィルターをクリア",
    "App settings" : "アプリ設定",
    "Users" : "ユーザー",
    "Groups" : "グループ",
    "Teams" : "チーム",
    "Other sources" : "他のソース",
    "Open conversations" : "オープンな会話",
    "No search results" : "検索結果なし",
    "Users and groups" : "ユーザーとグループ",
    "The meeting will start soon" : "会議はまもなく始まります",
    "This meeting is scheduled for {startTime}" : "この会議の予定は{startTime}です",
    "You are currently waiting in the lobby" : "現在ロビーで待機中",
    "Advanced" : "高度な",
    "Select microphone" : "マイクを選択",
    "No microphone available" : "利用可能なマイクがありません",
    "Select speaker" : "発言者を指定",
    "No speaker available" : "指定できる発言者がいません",
    "Select camera" : "カメラを選択",
    "No camera available" : "利用可能なカメラがありません",
    "Select a device" : "デバイスを選択する",
    "Test speakers" : "発言者をテスト",
    "Test" : "テスト",
    "Devices" : "端末",
    "Backgrounds" : "背景",
    "No audio" : "音声なし",
    "No camera" : "カメラがありません",
    "Display video as you will see it (mirrored)" : "鏡像表示でプレビューを表示",
    "Calls are not supported in your browser" : "お使いのブラウザーは通話に対応していません",
    "Access to microphone is only possible with HTTPS" : "マイクへのアクセスはHTTPSでのみ可能です",
    "Access to microphone was denied" : "マイクへのアクセスが拒否されました",
    "Error while accessing microphone" : "マイクへのアクセス中にエラーが発生しました",
    "Access to camera is only possible with HTTPS" : "カメラへのアクセスはHTTPSでのみ可能です",
    "The call is being recorded." : "通話は録音されています。",
    "The call might be recorded." : "通話は録音されるかもしれません。",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "レコーディングには、あなたの声、カメラからのビデオ、および画面共有が含まれる場合があります。通話に参加する前に、あなたの同意が必要です。",
    "Give consent to the recording of this call" : "この通話のレコーディングに同意してください",
    "Start recording immediately with the call" : "通話と同時にレコーディングを開始する",
    "Apply settings" : "設定を適用する",
    "Select virtual office background" : "仮想オフィスの背景を選択",
    "Select virtual home background" : "仮想ホームの背景を選択",
    "Select virtual abstract background" : "仮想抽象背景を選択",
    "Select virtual beach background" : "仮想ビーチの背景を選択",
    "Select virtual park background" : "仮想公園の背景を選択",
    "Select virtual theater background" : "仮想シアターの背景を選択",
    "Select virtual library background" : "仮想図書館の背景を選択",
    "Select virtual space station background" : "仮想宇宙ステーションの背景を選択",
    "Error while uploading the file" : "ファイルのアップロード中にエラーが発生しました",
    "Invalid path selected" : "無効なパスが選択されました",
    "Select virtual background from file {fileName}" : "ファイル {fileName} から仮想背景を選択します",
    "Blur" : "ぼかし",
    "Upload" : "アップロード",
    "Files" : "ファイル",
    "(editing)" : "(編集)",
    "(edited)" : "(編集済み)",
    "The message has expired or has been deleted" : "メッセージの有効期限が切れたか、削除されました",
    "Cancel quote" : "引用のキャンセル",
    "24 hours" : "24時間",
    "7 days" : "7日",
    "Clear reminder – {timeLocale}" : "リマインダーを消去 – {timeLocale}",
    "Edited by {actor}" : "編集者：{actor}",
    "Message text copied to clipboard" : "メッセージテキストがクリップボードにコピーされました",
    "Message text could not be copied" : "メッセージテキストはコピーできませんでした",
    "Message forwarded to \"Note to self\"" : "メッセージが「自分のメモ」に転送されました",
    "Error while forwarding message to \"Note to self\"" : "「自分のメモ」へメッセージ転送中にエラー",
    "A reminder was successfully removed" : "リマインダーの削除に成功しました",
    "Error occurred when removing a reminder" : "リマインダー削除時にエラーが発生しました",
    "A reminder was successfully set at {datetime}" : "リマインダーは {datetime} に正常に設定されました",
    "Error occurred when creating a reminder" : "リマインダー作成時にエラーが発生しました",
    "Add a reaction to this message" : "このメッセージにリアクションを追加",
    "Reply" : "返信",
    "More actions" : "その他のアクション",
    "Set reminder" : "リマインダーを設定",
    "Reply privately" : "個人的に返信する",
    "Edit message" : "メッセージを編集",
    "Copy message" : "メッセージをコピー",
    "Copy message link" : "メッセージリンクのコピー",
    "Go to file" : "ファイルへ移動",
    "Download file" : "ファイルをダウンロード",
    "Forward message" : "メッセージを転送する",
    "Translate" : "翻訳",
    "Set custom reminder" : "カスタムリマインダーを設定する",
    "Close reactions menu" : "リアクションメニューを閉じる",
    "React with {emoji}" : "{emoji} で反応する",
    "React with another emoji" : "他の絵文字で反応する",
    "Choose a conversation to forward the selected message." : "会話を選択して、選択したメッセージを転送します。",
    "Error while forwarding message" : "メッセージの転送中にエラーが発生しました",
    "The message has been forwarded to {selectedConversationName}" : "メッセージは{selectedConversationName}に転送されました",
    "Dismiss" : "閉じる",
    "Go to conversation" : "会話へ行く",
    "Detect language" : "言語を検出する",
    "The message could not be translated" : "メッセージは翻訳できませんでした",
    "Translation copied to clipboard" : "翻訳をクリップボードにコピーしました",
    "Translation could not be copied" : "翻訳をコピーできませんでした",
    "Translate message" : "メッセージの翻訳",
    "Source language to translate from" : "翻訳元の言語",
    "Translate from" : "翻訳元の言語",
    "Target language to translate into" : "翻訳先の言語",
    "Translate to" : "翻訳先",
    "Translating" : "翻訳する",
    "Copy translated text" : "翻訳されたテキストをコピー",
    "Send now" : "今すぐ送信",
    "Message read by everyone who shares their reading status" : "メッセージが読み込み状況を共有するすべてのメンバーに見られました",
    "Message sent" : "メッセージ送信済み",
    "Deleting message" : "メッセージを削除しています",
    "Message deleted successfully" : "メッセージが正常に削除されました",
    "Message could not be deleted because it is too old" : "メッセージが古すぎるため削除できませんでした",
    "Only normal chat messages can be deleted" : "通常のチャットメッセージのみを削除できます",
    "An error occurred while deleting the message" : "メッセージの削除中にエラーが発生しました",
    "Your browser does not support playing audio files" : "このブラウザーはオーディオファイルの再生をサポートしていません。",
    "Contact" : "連絡先",
    "{stack} in {board}" : "{board} 内の {stack}",
    "Deck Card" : "Deckカード",
    "Remove {fileName}" : "{fileName} を削除",
    "Open this location in OpenStreetMap" : "オープンストリートマップでこの場所を表示",
    "_%n reply_::_%n replies_" : ["%n件の返信"],
    "Sending message" : "メッセージ送信中",
    "Failed to send the message. Click to try again" : "メッセージの送信に失敗しました。クリックして再試行してください",
    "Not enough free space to upload file" : "ファイルをアップロードするのに十分な空き容量がありません",
    "You cannot send messages to this conversation at the moment" : "現在、この会話にメッセージを送信することはできません",
    "_%n vote_::_%n votes_" : ["%n投票数"],
    "Open poll" : "公開投票",
    "See results" : "結果を見る",
    "Reactions" : "リアクション",
    "No permission to post reactions in this conversation" : "この会話にリアクションを投稿する権限がありません",
    "Show all reactions" : "全てのリアクションを表示",
    "Add more reactions" : "その他のリアクションを追加",
    "Show or collapse system messages" : "システムメッセージを表示または折りたたむ",
    "No messages" : "メッセージはありません",
    "All messages have expired or have been deleted." : "全てのメッセージは期限切れまたは削除されました。",
    "Unpin" : "ピンの解除",
    "Cancel search" : "検索をキャンセルする",
    "Add a phone number" : "電話番号を追加する",
    "All set, the conversation \"{conversationName}\" was created." : "全ての設定が完了し、会話 \"{conversationName}\" が作成されました。",
    "Create a new group conversation" : "新規グループ会話の作成",
    "Add participants" : "参加者を追加",
    "Conversation visibility" : "会話の可視性",
    "Allow guests to join via link" : "リンク経由でのゲスト参加を許可",
    "Enter password" : "パスワードを入力してください",
    "This conversation has been locked" : "会話はロックされています",
    "No permission to post messages in this conversation" : "この会話にメッセージを投稿する権限がありません",
    "Joining conversation …" : "会話に参加中…",
    "Create a thread silently" : "非通知でスレッドを作成する",
    "Create a thread" : "スレッドを作成する",
    "Send message" : "メッセージを送信",
    "Send without notification" : "通知なしで送信",
    "The message could not be edited" : "メッセージを編集できませんでした",
    "File to share" : "共有するファイル",
    "Add emoji" : "絵文字を追加する",
    "Adding a mention will only notify users who did not read the message." : "メンションを追加すると、メッセージを読んでいないユーザーにのみ通知されます。",
    "Send later" : "後で送信する",
    "Cancel editing" : "編集をキャンセル",
    "{user} is out of office and might not respond." : "{user} は外出中で応答しない可能性があります。",
    "Share from {nextcloud}" : "{nextcloud} から共有する",
    "Share from Files" : "ファイルから共有",
    "Share files to the conversation" : "会話でファイルを共有する",
    "Upload from device" : "デバイスからアップロード",
    "Create new poll" : "投票を作成",
    "Smart picker" : "スマートピッカー",
    "Record voice message" : "ボイスメッセージを録音",
    "End recording and send" : "録音を終了して送信する",
    "Dismiss recording" : "録音をキャンセルする",
    "Access to the microphone was denied" : "マイクへのアクセスが拒否されました",
    "Microphone either not available or disabled in settings" : "マイクが使えないか、設定で無効になっています。",
    "Error while recording audio" : "音声録音中にエラーが発生しました",
    "New file" : "新しいファイル",
    "Blank" : "ブランク",
    "Error while creating file" : "ファイルの作成中にエラーが発生しました",
    "Create and share a new file" : "新しいファイルを作成し共有する",
    "Name of the new file" : "新しいファイルの名前",
    "Create file" : "ファイルを作成する",
    "Someone is typing …" : "誰かが入力中です...",
    "{user1} is typing …" : "{user1} は入力中です...",
    "{user1} and {user2} are typing …" : "{user1} と {user2} が入力中です...",
    "{user1}, {user2} and {user3} are typing …" : "{user1}、{user2}、{user3} が入力中です...",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}、{user2}、{user3} と他の %n 人が入力中です..."],
    "Add more files" : "さらにファイルを追加する",
    "Send" : "送信",
    "In this conversation <strong>{user}</strong> can:" : "この会話において、 <strong>{user}</strong> さんは次のことが可能です:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "<strong>{conversationName}</strong> の参加者のデフォルト権限を編集",
    "Start a call" : "通話を開始",
    "Skip the lobby" : "ロビーをスキップ",
    "Can post messages and reactions" : "メッセージとリアクションの投稿を許可",
    "Enable the microphone" : "マイクを有効にする",
    "Enable the camera" : "カメラを有効にする",
    "Share the screen" : "画面共有",
    "Update permissions" : "利用権限を更新",
    "Updating permissions" : "権限を更新中",
    "Create poll" : "投票を作成",
    "Question" : "質問",
    "Ask a question" : "質問する",
    "Answers" : "回答",
    "Answer {option}" : "回答 {option}",
    "Delete poll option" : "投票の選択肢を削除",
    "Add answer" : "回答を追加",
    "Settings" : "設定",
    "Anonymous poll" : "匿名投票",
    "Multiple answers" : "複数の答え",
    "You voted for this option" : "あなたはこの選択肢に投票しました",
    "End poll" : "投票終了",
    "Change your vote" : "投票内容を変更する",
    "Results" : "結果",
    "Voted participants" : "投票した参加者",
    "Send a message to \"{roomName}\"" : "\"{roomName}\" にメッセージを送る",
    "Hide list of participants" : "参加者のリストを非表示にする",
    "Show list of participants" : "参加者のリストを表示",
    "Assistance requested in {roomName}" : "{roomName} で援助を要請",
    "The message was sent to \"{roomName}\"" : "メッセージは \"{roomName}\" に送信されました",
    "Dismiss request for assistance" : "援助要請を却下する",
    "Send message to room" : "部屋にメッセージを送信",
    "Back to main room" : "メインルームに戻る",
    "Back to your room" : "自分の部屋に戻る",
    "Message all rooms" : "全てのルームにメッセージ",
    "Start session" : "セッションを開始する",
    "Start a call before you start a breakout room session" : "子会議室のセッションを始める前に通話を開始してください",
    "Stop session" : "セッションを停止する",
    "The message was sent to all breakout rooms" : "メッセージは全ての子会議室に送信されました",
    "Send a message to all breakout rooms" : "全ての子会議室にメッセージを送る",
    "Breakout rooms are not started" : "子会議室が開始されていません",
    "Calls without High-performance backend can cause connectivity issues and high load on devices. {linkstart}Learn more{linkend}" : "高性能バックエンドを使用しない通話では、接続の問題が発生し、デバイスに高負荷がかかる可能性があります。{linkstart}詳細{linkend}",
    "Disable lobby" : "ロビーを無効にする",
    "Settings for participant \"{user}\"" : "参加者\"{user}\"の設定",
    "Participant \"{user}\"" : "参加者 \"{user}\"",
    "moderator" : "モデレータ",
    "bot" : "ボット",
    "guest" : "ゲスト",
    "Ringing …" : "鳴っています...",
    "Call rejected" : "通話拒否",
    "{time} talking …" : "{time} 話しています…",
    "{time} talking time" : "{time} 通話時間",
    "Raised their hand" : "手を上げる",
    "Joined with video" : "ビデオで参加",
    "Joined via phone" : "電話で参加",
    "Joined with audio" : "オーディオで参加",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "テキストの長さは {maxLength} 文字以下である必要があります。現在のテキストの長さは {charactersCount} 文字です。",
    "Remove group and members" : "メンバーとグループを削除",
    "Remove team and members" : "チーム・グループとメンバーを削除",
    "Remove participant" : "参加者を削除",
    "Notification was sent to {displayName}" : "{displayName} さんに通知が送信されました",
    "Could not send notification to {displayName}" : "{displayName} さんに通知を送信できませんでした",
    "Permissions granted to {displayName}" : "{displayName}に権限が付与されました",
    "Could not modify permissions for {displayName}" : "{displayName}の権限を変更できませんでした",
    "Permissions removed for {displayName}" : "{displayName}の権限が削除されました",
    "Permissions set to default for {displayName}" : "{displayName} さんにデフォルト権限が設定されました",
    "Phone number could not be hung up" : "電話が切れませんでした",
    "Phone number could not be put on hold" : "電話を保留にできませんでした",
    "Phone number could not be muted" : "電話をミュートできませんでした",
    "Phone number could not be unmuted" : "電話をミュート解除できませんでした",
    "DTMF message could not be sent" : "DTMFメッセージを送信できませんでした",
    "Phone number copied to clipboard" : "電話番号がクリップボードにコピーされた",
    "Phone number could not be copied" : "電話番号はコピーできませんでした",
    "in the lobby" : "ロビーで",
    "Dial out phone" : "電話をかける",
    "Hang up phone" : "電話を切る",
    "Move back to lobby" : "ロビーに戻る",
    "Move to conversation" : "会話へ移動する",
    "Dial-in PIN" : "ダイヤルインPIN",
    "Demote from moderator" : "モデレータから降格",
    "Promote to moderator" : "モデレータに昇格",
    "Resend invitation" : "招待状を再送する",
    "Send call notification" : "通話通知を送信",
    "Dial out phone number" : "電話番号をかける",
    "Resume call for phone number" : "電話番号にかけ直す",
    "Put phone number on hold" : "電話番号を保留にする",
    "Unmute phone number" : "電話番号のミュートを解除する",
    "Mute phone number" : "電話番号のミュート",
    "Copy phone number" : "電話番号をコピーする",
    "Reset custom permissions" : "カスタム権限をリセット",
    "Grant all permissions" : "すべての権限を付与",
    "Remove all permissions" : "すべての権限を削除",
    "Remove" : "削除",
    "Permissions modified for {displayName}" : "{displayName}の権限が変更されました",
    "Add users or groups" : "ユーザーまたはグループの追加",
    "Add users" : "ユーザーを追加",
    "Add groups" : "グループを追加",
    "Add other sources" : "他のソースを追加",
    "Add emails" : "メールを追加",
    "Integrations" : "インテグレーション",
    "Add federated users" : "フェデレーションユーザーを追加",
    "Searching …" : "検索しています…",
    "Search for more users" : "さらにユーザーを探す",
    "Search or add participants" : "参加者を検索して追加する",
    "Invitation was sent to {actorId}" : "招待が {actorId} に送信されました",
    "An error occurred while adding the participants" : "参加者の追加中にエラーが発生しました",
    "Participants" : "参加者",
    "Participants ({count})" : "参加者 ({count})",
    "Open chat" : "チャットを始める",
    "You have new unread messages in the chat." : "チャットに未読のメッセージがあります",
    "You have been mentioned in the chat." : "チャットであなたについてのメッセージがありました。",
    "Chat" : "チャット",
    "Details" : "詳細",
    "Shared items" : "共有済みアイテム",
    "No results found" : "結果が見つかりません",
    "Load more results" : "結果をさらに読み込む",
    "Projects" : "プロジェクト",
    "No shared items" : "共有アイテムがありません",
    "Thread notifications" : "スレッド通知",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "会話へのリンク",
    "No open conversations found" : "公開している会話は見つかりませんでした",
    "Either there are no open conversations or you joined all of them." : "開いている会話が存在しないか、あなたはすべてに参加しています。",
    "Check spelling or use complete words." : "スペルをチェックするか、完全な単語を使用してください。",
    "Search conversations or users" : "会話やユーザーを検索",
    "Select conversation" : "会話を選択",
    "Number length is not valid" : "番号の長さが無効",
    "Region code is not valid" : "有効な地域コードではありません",
    "Number length is too short" : "番号の長さが短すぎます",
    "Number length is too long" : "番号の長さが長すぎます",
    "Number is not valid" : "番号は有効なものではありません",
    "Phone numbers" : "電話番号",
    "Display name: {name}" : "表示名: {name}",
    "Edit display name" : "表示名の編集",
    "Save name" : "名前を保存",
    "Error while saving sounds setting" : "サウンド設定を保存するときにエラー",
    "Compact conversations list" : "会話リストをシンプルに表示",
    "Play sounds when participants join or leave a call" : "参加者が通話に参加したとき、または通話を離れたときにサウンドを再生する",
    "Currently not available on iPhone and iPad due to technical restrictions by the manufacturer" : "現在、メーカーによる技術的制限によりiPhoneおよびiPadではご利用いただけません。",
    "Notification settings" : "通知設定",
    "Sounds for chat and call notifications" : "チャットや着信時の通知",
    "Default language" : "デフォルトの言語",
    "Select location for attachments" : "添付ファイルの場所を選択します",
    "Error while setting attachment folder" : "添付ファイル用フォルダー設定中のエラー",
    "Error while setting read status privacy" : "読み取りステータスのプライバシー設定中にエラーが発生しました",
    "Error while setting typing status privacy" : "タイピングステータスのプライバシー設定中にエラーが発生しました",
    "Turn camera and microphone off by default" : "自動的にカメラとマイクをオフにする",
    "Blur camera background by default" : "自動的に背景をぼかす",
    "Skip device preview before joining a call" : "通話に参加する前のデバイスのプレビューをスキップする",
    "Appearance & Sounds" : "外観と通知",
    "Privacy" : "プライバシー",
    "Send read receipts" : "既読ステータス",
    "When off, all read statuses will be hidden" : "この機能をオフにすると、すべての既読ステータスが非表示になります。",
    "Share typing status" : "入力状態を共有",
    "When off, all typing indicators will be hidden" : "この機能をオフにすると、すべての入力インジケーターが非表示になります。",
    "Attachments folder" : "添付ファイルフォルダー",
    "Toggle full screen" : "全画面に切り替え",
    "Return to Home screen" : "ホーム画面に戻る",
    "Search" : "検索",
    "Shortcuts while in a chat" : "チャット中のショートカット",
    "Focus the chat input" : "チャット入力欄に移行",
    "Unfocus the chat input to use shortcuts" : "ショートカットを使用するには、チャット入力欄からカーソルを外す",
    "Edit your last message" : "最後のメッセージを編集する",
    "Shortcuts while in a call" : "通話中のショートカット",
    "Camera on and off" : "カメラのオンとオフ",
    "Microphone on and off" : "マイクのオンとオフ",
    "Raise or lower hand" : "手を上げるまたは下げる",
    "Push to talk or push to mute" : "押して話すか、押してミュート",
    "Zoom-in / zoom-out a screen share" : "画面共有のズームイン/ズームアウト",
    "Start call silently" : "サイレント通話を開始",
    "Start call" : "通話を開始",
    "End call" : "通話終了",
    "You will be able to join the call only after a moderator starts it." : "あなたは、モデレーターが通話を開始し後に通話参加できるようになります。",
    "End call for everyone" : "全員の通話を終了する",
    "Starting the recording" : "録画を開始",
    "Recording" : "記録中",
    "The call has been running for one hour." : "通話が1 時間経過しました。",
    "Cancel recording start" : "録画開始をキャンセル",
    "Stop recording" : "録画を停止",
    "Raise hand" : "挙手 (r)",
    "Raise hand (R)" : "挙手 (R)",
    "Lower hand" : "手を下げる (r)",
    "Lower hand (R)" : "手を下げる (R)",
    "Send a reaction" : "リアクションを送信",
    "React with {reaction}" : "{reaction} で反応する",
    "All tasks done!" : "すべてのタスクが完了しました!",
    "_%n participant in call_::_%n participants in call_" : ["%n 人が通話に参加"],
    "You are not allowed to enable screensharing" : "画面共有を許可されていません",
    "No screensharing" : "画面共有不可",
    "Screensharing options" : "画面共有オプション",
    "Enable screensharing" : "画面共有を有効にする",
    "Bad sent video and screen quality." : "送信されている映像と画像の品質がよくありません。",
    "Bad sent screen quality." : "送信画面の品質がよくありません。",
    "Bad sent video quality." : "送信映像の品質が良くありません。",
    "Bad sent audio, video and screen quality." : "送信音声と映像と画面の品質が良くありません。",
    "Bad sent audio and screen quality." : "送信音声と画面の品質が良くありません。",
    "Bad sent audio and video quality." : "送信音声と映像の品質が良くありません。",
    "Bad sent audio quality." : "送信音声の品質が良くありません。",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "コンピュータかネットワークの負荷が高いため、他の参加者が画面を見ることができない場合があります。状況を改善するには、画面共有を行っている間、背景ぼかしまたはビデオを無効にしてみてください。",
    "Disable background blur" : "背景のぼかしを止める",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "コンピューターかネットワークの負荷が高い為、他の参加者から見えていない可能性があります。改善するためにカメラか画面共有をオフにしてみてください。",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "インターネットかコンピューターの負荷が高いため、他の参加者にはこちらの画面は見えていないかもしれません。",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "インターネット接続かコンピューターの負荷が高いため、他の参加者にはあなたが見えていないかもしれません。",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "コンピューターかネットワークの負荷が高いため、他の参加者が画面を見ることができない場合があります。状況を改善するには、画面共有を行っている間、背景のぼかしまたはビデオを無効にしてみてください。",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "インターネット接続かコンピューターの負荷が高いため、他の参加者から見えず、どうなっているのか分からないかもしれません。この状態を改善するには、画面共有していたら映像を停止してみてください。",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "インターネット接続かコンピューターの負荷が高いため、他の参加者から見えず、どうなっているのか分からないかもしれません。この状態を改善するには、画面共有を停止してみてください。",
    "Disable screenshare" : "画面共有を無効",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "インターネット接続かコンピューターの負荷が高いため、他の参加者から見えず、どうなっているのか分からないかもしれません。この状態を改善するには、背景のぼかしを止めるか、映像を停止してみてください。",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "インターネット接続かコンピューターの負荷が高いため、他の参加者から見えず、どうなっているのか分からないかもしれません。この状態を改善するには、映像を停止してみてください。",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "インターネット接続かコンピューターの負荷が高いため、他の参加者にはあなたがどうなっているのか分からないかもしれません。",
    "Screen sharing is not supported by your browser." : "お使いのブラウザーは画面共有をサポートしていません。",
    "Screen sharing requires the page to be loaded through HTTPS." : "画面共有はHTTPSが必要です。",
    "Screensharing requires the page to be loaded through HTTPS." : "画面共有はHTTPSが必要です。",
    "An error occurred while starting screensharing." : "画面共有の開始中にエラーが発生しました。",
    "Show your screen" : "自分の画面を表示",
    "Stop screensharing" : "画面共有を停止",
    "Mute others" : "他の人をミュートする",
    "Start recording" : "録画を開始",
    "Set up breakout rooms" : "子会議室を設定",
    "Open Calendar" : "カレンダーを開く",
    "Remove participant {name}" : "参加者 {name} を削除する",
    "Delete now" : "今すぐ削除",
    "Keep" : "保持",
    "Open dialpad" : "ダイヤルパッドを開く",
    "Select a region" : "地域を選択してください",
    "Search …" : "検索…",
    "Message without mention" : "話しの無いメッセージ",
    "Mention myself" : "自分自身の話し",
    "Mention everyone" : "全員にメンション",
    "Select a conversation" : "会話を選択",
    "Select a mode" : "モードを選択する",
    "The conversation does not exist" : "会話が存在しません",
    "Join a conversation or start a new one!" : "会話に参加または開始する！",
    "Join a conversation or start a new one" : "会話に参加または開始する",
    "Nextcloud URL" : "Nextcloud URL",
    "Nextcloud user" : "Nextcloud ユーザー",
    "User password" : "ユーザーのパスワード",
    "Talk conversation" : "会話",
    "Skip TLS verification" : "TLS検証をスキップする",
    "Matrix server URL" : "Matrix サーバー URL",
    "User" : "ユーザー",
    "Matrix channel" : "Matrix チャンネル",
    "Mattermost server URL" : "Mattermost サーバーのURL",
    "Mattermost user" : "Mattermost ユーザー",
    "Team name" : "チーム名",
    "Channel name" : "チャンネル名",
    "Rocket.Chat server URL" : "Rocket.Chat サーバーURL",
    "User name or email address" : "名前またはメールアドレス",
    "Rocket.Chat channel" : "Rocket.Chat チャンネル",
    "Zulip server URL" : "Zulip サーバーURL",
    "Bot user name" : "Botユーザー名",
    "Bot API key" : "Bot APIキー",
    "Zulip channel" : "Zulip チャンネル",
    "API token" : "APIトークン",
    "Slack channel" : "Slackチャンネル",
    "Server ID or name" : "サーバーIDまたは名前",
    "Channel" : "チャンネル",
    "Login" : "ログイン",
    "Chat ID" : "チャットID",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "IRC サーバーURL (e.g. chat.freenode.net:6667)",
    "Nickname" : "ニックネーム",
    "Connection password" : "接続パスワード",
    "IRC channel" : "IRC チャンネル",
    "Channel password" : "チャネルパスワード",
    "NickServ nickname" : "NickServ ニックネーム",
    "NickServ password" : "NickServ パスワード",
    "Use TLS" : "TLSを使用する",
    "Use SASL" : "SASLを使用する",
    "Tenant ID" : "テナントID",
    "Client ID" : "クライアントID",
    "Team ID" : "チームID",
    "Thread ID" : "スレッドID",
    "XMPP/Jabber server URL" : "XMPP/Jabber サーバーURL",
    "MUC server URL" : "MUC サーバーURL",
    "Jabber ID" : "Jabber ID",
    "Media" : "メディア",
    "Polls" : "投票",
    "Deck cards" : "Deckカード",
    "Voice messages" : "ボイスメッセージ",
    "Locations" : "場所",
    "Call recordings" : "通話のレコーディング",
    "Audio" : "オーディオ",
    "Show all media" : "全てのメディアを表示",
    "Show all files" : "すべてのファイルを表示",
    "Show all polls" : "すべての投票を表示",
    "Show all deck cards" : "全てのDeckカードを表示",
    "Show all voice messages" : "全てのボイスメッセージを表示",
    "Show all locations" : "全ての位置を表示",
    "Show all call recordings" : "すべての通話録音を表示",
    "Show all audio" : "全ての音声を表示",
    "Show all other" : "そのほか全てを表示",
    "Group" : "グループ",
    "Team" : "チーム",
    "You reconnected to the call" : "通話に再接続しました",
    "{actor} reconnected to the call" : "{actor} が通話に再接続しました",
    "You added {user0} and {user1}" : "{user0} と {user1} を追加しました",
    "_You added {user0}, {user1} and %n more participant_::_You added {user0}, {user1} and %n more participants_" : ["あなたは {user0}、{user1}、および %n人の参加者を追加しました"],
    "An administrator added you and {user0}" : "管理者があなたと {user0} を追加しました",
    "{actor} added you and {user0}" : "{actor} があなたと {user0} を追加しました",
    "_An administrator added you, {user0} and %n more participant_::_An administrator added you, {user0} and %n more participants_" : ["管理者があなた、{user0} ともう%n人の参加者を追加しました"],
    "_{actor} added you, {user0} and %n more participant_::_{actor} added you, {user0} and %n more participants_" : ["{actor} があなた、{user0}、および%n人の参加者を追加しました"],
    "An administrator added {user0} and {user1}" : "管理者が {user0} と {user1} を追加しました",
    "{actor} added {user0} and {user1}" : "{actor} は {user0} と {user1} を追加しました",
    "_An administrator added {user0}, {user1} and %n more participant_::_An administrator added {user0}, {user1} and %n more participants_" : ["管理者が {user0}、{user1} ともう%n人の参加者を追加しました"],
    "_{actor} added {user0}, {user1} and %n more participant_::_{actor} added {user0}, {user1} and %n more participants_" : ["{actor} が {user0}、{user1} および%n人の参加者を追加しました"],
    "You and {user0} joined the call" : "あなたと {user0} が通話に参加しました",
    "_You, {user0} and %n more participant joined the call_::_You, {user0} and %n more participants joined the call_" : ["あなた、{user0} と %n 人の参加者が通話に参加しました"],
    "{user0} and {user1} joined the call" : "{user0} と {user1} が通話に参加しました",
    "_{user0}, {user1} and %n more participant joined the call_::_{user0}, {user1} and %n more participants joined the call_" : ["{user0}、{user1} と %n 人の参加者が通話に参加しました"],
    "You and {user0} left the call" : "あなたと {user0} が通話から退出しました",
    "_You, {user0} and %n more participant left the call_::_You, {user0} and %n more participants left the call_" : ["あなた、{user0} と %n 人の参加者が通話から退出しました"],
    "{user0} and {user1} left the call" : "{user0} と {user1} が通話から退出しました",
    "_{user0}, {user1} and %n more participant left the call_::_{user0}, {user1} and %n more participants left the call_" : ["{user0}、{user1} と %n 人の参加者が通話から退出しました"],
    "You promoted {user0} and {user1} to moderators" : "あなたは {user0} と {user1} をモデレーターに昇進させました",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["{user0}、{user1}、さらに%n人の参加者をモデレーターに昇格させました"],
    "An administrator promoted you and {user0} to moderators" : "管理者があなたと {user0} をモデレータに昇格させました",
    "{actor} promoted you and {user0} to moderators" : "{actor} があなたと {user0} をモデレーターに昇進させました",
    "_An administrator promoted you, {user0} and %n more participant to moderators_::_An administrator promoted you, {user0} and %n more participants to moderators_" : ["管理者があなた、{user0}、および%n人の参加者をモデレーターに昇格させました"],
    "_{actor} promoted you, {user0} and %n more participant to moderators_::_{actor} promoted you, {user0} and %n more participants to moderators_" : ["{actor} があなた、{user0}、および%n人の参加者をモデレーターに昇格させました"],
    "An administrator promoted {user0} and {user1} to moderators" : "管理者が {user0} と {user1} をモデレータに昇格させました",
    "{actor} promoted {user0} and {user1} to moderators" : "{actor} が {user0} と {user1} をモデレーターに昇進させました",
    "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["管理者が {user0}、{user1}、さらに%n人の参加者をモデレーターに昇格させました"],
    "_{actor} promoted {user0}, {user1} and %n more participant to moderators_::_{actor} promoted {user0}, {user1} and %n more participants to moderators_" : ["{actor} が {user0}、{user1}、さらに%n人の参加者をモデレーターに昇格させました"],
    "You demoted {user0} and {user1} from moderators" : "あなたは {user0} と {user1} をモデレーターから降格しました",
    "_You demoted {user0}, {user1} and %n more participant from moderators_::_You demoted {user0}, {user1} and %n more participants from moderators_" : ["あなたは {user0}、{user1}、さらに%n人の参加者をモデレーターから降格しました"],
    "An administrator demoted you and {user0} from moderators" : "管理者があなたと {user0} をモデレータから降格しました",
    "{actor} demoted you and {user0} from moderators" : "{actor} があなたと {user0} をモデレーターから降格しました",
    "_An administrator demoted you, {user0} and %n more participant from moderators_::_An administrator demoted you, {user0} and %n more participants from moderators_" : ["管理者があなた、{user0}、および%n人の参加者をモデレーターから降格しました"],
    "_{actor} demoted you, {user0} and %n more participant from moderators_::_{actor} demoted you, {user0} and %n more participants from moderators_" : ["{actor} があなた、{user0}、および%n人の参加者をモデレーターから降格しました"],
    "An administrator demoted {user0} and {user1} from moderators" : "管理者が {user0} と {user1} をモデレータから降格しました",
    "{actor} demoted {user0} and {user1} from moderators" : "{actor} が {user0} と {user1} をモデレーターから降格しました",
    "_An administrator demoted {user0}, {user1} and %n more participant from moderators_::_An administrator demoted {user0}, {user1} and %n more participants from moderators_" : ["管理者が {user0}、{user1}、および%n人の参加者をモデレーターから降格しました"],
    "_{actor} demoted {user0}, {user1} and %n more participant from moderators_::_{actor} demoted {user0}, {user1} and %n more participants from moderators_" : ["{actor} が {user0}、{user1}、さらに%n人の参加者をモデレーターから降格しました"],
    "You: {lastMessage}" : "あなた: {lastMessage}",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "(edited by you)" : "(あなたが編集しました)",
    "(edited by a deleted user)" : "(削除済みユーザーにより編集されました)",
    "(edited by {moderator})" : "({moderator} により編集されました)",
    "The recording failed. Please contact your administrator." : "レコーディングが失敗しました。あなたの管理者に連絡してください。",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "別ウィンドウかデバイスで既に会話に参加済みです。現在、複数接続はNextcloud Talkではサポートされていません。どうしますか？",
    "Leave this page" : "このページを離れる",
    "Join here" : "参加する",
    "Deck card has been posted to {conversation}" : "デッキカードが {conversation} に投稿されました",
    "An error occurred while posting deck card to conversation" : "Deckカードを会話に投稿中にエラーが発生しました",
    "Post to a conversation" : "会話に投稿する",
    "Post to conversation" : "会話に投稿する",
    "Location has been posted to {conversation}" : "場所が {conversation} に投稿されました",
    "An error occurred while posting location to conversation" : "位置情報を会話に投稿中にエラーが発生しました",
    "Share to a conversation" : "会話に共有",
    "Share to conversation" : "会話に共有",
    "In conversation" : "会話の中で",
    "Search in conversation: {conversation}" : "会話で検索する: {conversation}",
    "Error while clearing conversation history" : "会話履歴のクリア中にエラーが発生しました",
    "Error occurred while allowing guests" : "ゲストの許可中にエラーが発生しました",
    "Error occurred while disallowing guests" : "ゲスト参加の禁止中にエラーが発生しました",
    "Error occurred when restricting the conversation to moderator" : "会話をモデレーターに制限するとエラーが発生しました",
    "Error occurred when opening the conversation to everyone" : "全員に会話を開くときにエラーが発生しました",
    "Conversation password has been saved" : "会話のパスワードが保存されました",
    "Conversation password has been removed" : "会話のパスワードが削除されました",
    "Error occurred while saving conversation password" : "会話のパスワードの保存中にエラーが発生しました",
    "Call recording is starting." : "録画を開始しています。",
    "Call recording stopped while starting." : "録画開始中にが停止しました。",
    "Call recording stopped. You will be notified once the recording is available." : "録画が停止されました。録画が利用可能になると通知が届きます",
    "Conversation picture set" : "会話画像設定する",
    "Conversation picture deleted" : "会話画像は削除されました",
    "Could not delete the conversation picture" : "会話画像を削除することができませんでした",
    "Could not post message: {errorMessage}" : "メッセージを投稿できませんでした: {errorMessage}",
    "An error occurred while fetching the participants" : "参加者の取得中にエラーが発生しました。",
    "Could not send invitation to {actorId}" : "{actorId} に招待状を送信できませんでした",
    "Invitations sent" : "招待が送信されました",
    "Error occurred when sending invitations" : "招待状の送信中にエラーが発生しました",
    "An error occurred while creating breakout rooms" : "子会議室の作成中にエラーが発生しました",
    "An error occurred while re-ordering the attendees" : "出席者の並び替え中にエラーが発生しました",
    "An error occurred while deleting breakout rooms" : "子会議室の削除中にエラーが発生しました",
    "An error occurred while starting breakout rooms" : "子会議室の開始中にエラーが発生しました",
    "An error occurred while stopping breakout rooms" : "子会議室の停止中にエラーが発生しました",
    "An error occurred while sending a message to the breakout rooms" : "子会議室へのメッセージの送信中にエラーが発生しました",
    "An error occurred while requesting assistance" : "アシスタントの要求中にエラーが発生しました。",
    "An error occurred while resetting the request for assistance" : "アシスタントの要求をリセットする際にエラーが発生しました",
    "An error occurred while joining breakout room" : "子会議室への参加中にエラーが発生しました",
    "Error fetching upcoming reminders" : "今後のリマインダー取得エラー",
    "An error occurred while accepting an invitation" : "招待の受諾時にエラーが発生しました",
    "An error occurred while rejecting an invitation" : "招待を拒否する時にエラーが発生しました",
    "{guest} (guest)" : "{guest} (ゲスト)",
    "An error occurred while submitting your vote" : "あなたの投票を送信する際にエラーが発生しました",
    "An error occurred while ending the poll" : "投票を終了する際にエラーが発生しました",
    "Poll \"{name}\" was created by {user}. Click to vote" : "\"{user}\" が作成した投票 \"{name}\" です。投票するにはクリックしてください。",
    "Failed to add reaction" : "リアクションの追加に失敗",
    "Failed to remove reaction" : "リアクションの削除に失敗",
    "Error while uploading file \"{fileName}\"" : "ファイル \"{fileName}\" のアップロード中にエラーが発生しました",
    "Not enough free space to upload file \"{fileName}\"" : "ファイル ”{fileName}\" をアップロードするのに十分な空き容量がありません",
    "You are not allowed to share files" : "ファイル共有は許可されていません",
    "Error while sharing file" : "ファイルの共有中にエラーが発生しました",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "お使いのブラウザーは、Nextcloud Talkで完全にはサポートされていません。最新バージョンのMozilla Firefox、Microsoft Edge、Google Chrome、Opera、またはApple Safariを使用してください。",
    "_%n hour_::_%n hours_" : ["%n時間"],
    "_%n day_::_%n days_" : ["%n日"],
    "_%n week_::_%n weeks_" : ["%n週間"],
    "Later today – {timeLocale}" : "今日この後 – {timeLocale}",
    "Tomorrow – {timeLocale}" : "明日 – {timeLocale}",
    "This weekend – {timeLocale}" : "今週末 – {timeLocale}",
    "Next week – {timeLocale}" : "来週 – {timeLocale}",
    "Message link copied to clipboard" : "メッセージリンクがクリップボードにコピーされました",
    "Conversation link copied to clipboard" : "会話リンクをクリップボードにコピーしました",
    "The link could not be copied" : "リンクをコピーできませんでした",
    "Sending signaling message has failed" : "シグナリングメッセージの送信に失敗しました",
    "Lost connection to signaling server. Trying to reconnect." : "シグナリングサーバーへの接続が切れました。再接続してみてください。",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "設定済みのシグナルサーバーは、このバージョンのTalkと互換性を持たせるために更新する必要があります。管理者に連絡してください。",
    "Please reload the page." : "ページをリロードしてください。",
    "Do not disturb" : "取り込み中",
    "Away" : "離席中",
    "Microphone {number}" : "マイク {number}",
    "Camera {number}" : "カメラ {number}",
    "Speaker {number}" : "スピーカー {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "ミュートしたまま話しているようです。他の人に聞こえるようにミュートを解除してください。",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "少なくとも1人の参加者との接続を確立できませんでした。あなたのシナリオにはTURNサーバーが必要かもしれません。管理者に依頼して、{linkstart}このドキュメント{linkend}に従って設定してください。",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "予想以上に時間がかかっています。メディア権限はすでに付与されていますか？（または拒否されていますか？）付与されている場合、オーディオとビデオが破損しているのでブラウザーを再起動してください。",
    "Access to microphone & camera is only possible with HTTPS" : "マイクとカメラへのアクセスはHTTPSでのみ可能です",
    "Please move your setup to HTTPS" : "HTTPSを使用して設定してください",
    "Access to microphone & camera was denied" : "マイクとカメラへのアクセスが拒否されました",
    "WebRTC is not supported in your browser" : "お使いのブラウザーはWebRTCに対応していません",
    "Please use a different browser like Firefox or Chrome" : "別のブラウザー（Firefox または Chrome 等）を使用してください",
    "Error while accessing microphone & camera" : "マイクとカメラのアクセス中にエラーが発生しました",
    "%s Talk on your mobile devices" : "あなたのモバイルデバイス上の会話%s",
    "Join conversations at any time, anywhere, on any device." : "いつでも、どこでも、どんなデバイスでも会話に参加できます。",
    "Android app" : "Android アプリ",
    "iOS app" : "iOS アプリ",
    "__language_name__" : "日本語 (Japanese)",
    "Tasks" : "タスク",
    "Notes" : "Notes",
    "Reports" : "報告",
    "Talk to %s" : "%s と通話",
    "Next meeting" : "次の会議",
    "Schedule a meeting from your calendar. A Talk conversation needs to be set as location to show up here" : "カレンダーに会議を予約します。ここに表示するためには、会議の場所にTalkのチャットルームを指定してください。",
    "Join conversations from remote Nextcloud servers" : "リモートNextcloudサーバーから会話に参加する",
    "Set reminder for later today" : "今日中にリマインダーを設定する",
    "Set reminder for tomorrow" : "明日のリマインダーを設定する",
    "Set reminder for this weekend" : "今週末のリマインダーを設定する",
    "Set reminder for next week" : "来週のリマインダーを設定する",
    "Open poll • You voted already" : "公開投票 • あなたは既に投票済み",
    "Open poll • Click to vote" : "公開投票 • クリックして投票",
    "Poll • Ended" : "投票 • 終了",
    "Talk recording from {time} ({conversation})" : " {time} からのトーク録音 ({conversation})",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["投票結果 • %n 投票"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["公開投票 • %n 投票"],
    "Submit vote" : "投票する",
    "Your privacy setting has been saved" : "プライバシー設定が保存されました",
    "Failed to save sounds setting" : "サウンド設定を保存できませんでした",
    "Sounds setting saved" : "サウンド設定を保存",
    "Always shown if recording consent is required" : "録音の同意が必要な場合は常に表示されます",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "別ウィンドウかデバイスで既に会話に参加済みです。現在、複数接続はNextcloud Talkではサポートされていないため、このセッションは閉じられます。"
},
"nplurals=1; plural=0;");
